.*: Assembler messages:
.*: Error: illegal operands `th.dcache.call x1'
.*: Error: illegal operands `th.dcache.ciall x1'
.*: Error: illegal operands `th.dcache.iall x1'
.*: Error: illegal operands `th.dcache.cpa 0\(x1\)'
.*: Error: illegal operands `th.dcache.cipa 0\(x1\)'
.*: Error: illegal operands `th.dcache.ipa 0\(x1\)'
.*: Error: illegal operands `th.dcache.cva 0\(x1\)'
.*: Error: illegal operands `th.dcache.civa 0\(x1\)'
.*: Error: illegal operands `th.dcache.iva 0\(x1\)'
.*: Error: illegal operands `th.dcache.csw 0\(x1\)'
.*: Error: illegal operands `th.dcache.cisw 0\(x1\)'
.*: Error: illegal operands `th.dcache.isw 0\(x1\)'
.*: Error: illegal operands `th.dcache.cpal1 0\(x1\)'
.*: Error: illegal operands `th.dcache.cval1 0\(x1\)'
.*: Error: illegal operands `th.icache.iall x1'
.*: Error: illegal operands `th.icache.ialls x1'
.*: Error: illegal operands `th.icache.ipa 0\(x1\)'
.*: Error: illegal operands `th.icache.iva 0\(x1\)'
.*: Error: illegal operands `th.l2cache.call x1'
.*: Error: illegal operands `th.l2cache.ciall x1'
.*: Error: illegal operands `th.l2cache.iall x1'
