.*: Assembler messages:
.*:4: Error: opcode not supported on this processor: .* \(.*\) `lwc2 \$0,0\(\$0\)'
.*:5: Error: opcode not supported on this processor: .* \(.*\) `lwc2 \$1,0\(\$0\)'
.*:6: Error: opcode not supported on this processor: .* \(.*\) `lwc2 \$2,0\(\$0\)'
.*:7: Error: opcode not supported on this processor: .* \(.*\) `lwc2 \$3,0\(\$0\)'
.*:8: Error: opcode not supported on this processor: .* \(.*\) `lwc2 \$4,0\(\$0\)'
.*:9: Error: opcode not supported on this processor: .* \(.*\) `lwc2 \$5,0\(\$0\)'
.*:10: Error: opcode not supported on this processor: .* \(.*\) `lwc2 \$6,0\(\$0\)'
.*:11: Error: opcode not supported on this processor: .* \(.*\) `lwc2 \$7,0\(\$0\)'
.*:12: Error: opcode not supported on this processor: .* \(.*\) `lwc2 \$8,0\(\$0\)'
.*:13: Error: opcode not supported on this processor: .* \(.*\) `lwc2 \$9,0\(\$0\)'
.*:14: Error: opcode not supported on this processor: .* \(.*\) `lwc2 \$10,0\(\$0\)'
.*:15: Error: opcode not supported on this processor: .* \(.*\) `lwc2 \$11,0\(\$0\)'
.*:16: Error: opcode not supported on this processor: .* \(.*\) `lwc2 \$12,0\(\$0\)'
.*:17: Error: opcode not supported on this processor: .* \(.*\) `lwc2 \$13,0\(\$0\)'
.*:18: Error: opcode not supported on this processor: .* \(.*\) `lwc2 \$14,0\(\$0\)'
.*:19: Error: opcode not supported on this processor: .* \(.*\) `lwc2 \$15,0\(\$0\)'
.*:20: Error: opcode not supported on this processor: .* \(.*\) `lwc2 \$16,0\(\$0\)'
.*:21: Error: opcode not supported on this processor: .* \(.*\) `lwc2 \$17,0\(\$0\)'
.*:22: Error: opcode not supported on this processor: .* \(.*\) `lwc2 \$18,0\(\$0\)'
.*:23: Error: opcode not supported on this processor: .* \(.*\) `lwc2 \$19,0\(\$0\)'
.*:24: Error: opcode not supported on this processor: .* \(.*\) `lwc2 \$20,0\(\$0\)'
.*:25: Error: opcode not supported on this processor: .* \(.*\) `lwc2 \$21,0\(\$0\)'
.*:26: Error: opcode not supported on this processor: .* \(.*\) `lwc2 \$22,0\(\$0\)'
.*:27: Error: opcode not supported on this processor: .* \(.*\) `lwc2 \$23,0\(\$0\)'
.*:28: Error: opcode not supported on this processor: .* \(.*\) `lwc2 \$24,0\(\$0\)'
.*:29: Error: opcode not supported on this processor: .* \(.*\) `lwc2 \$25,0\(\$0\)'
.*:30: Error: opcode not supported on this processor: .* \(.*\) `lwc2 \$26,0\(\$0\)'
.*:31: Error: opcode not supported on this processor: .* \(.*\) `lwc2 \$27,0\(\$0\)'
.*:32: Error: opcode not supported on this processor: .* \(.*\) `lwc2 \$28,0\(\$0\)'
.*:33: Error: opcode not supported on this processor: .* \(.*\) `lwc2 \$29,0\(\$0\)'
.*:34: Error: opcode not supported on this processor: .* \(.*\) `lwc2 \$30,0\(\$0\)'
.*:35: Error: opcode not supported on this processor: .* \(.*\) `lwc2 \$31,0\(\$0\)'
.*:37: Error: opcode not supported on this processor: .* \(.*\) `swc2 \$0,0\(\$0\)'
.*:38: Error: opcode not supported on this processor: .* \(.*\) `swc2 \$1,0\(\$0\)'
.*:39: Error: opcode not supported on this processor: .* \(.*\) `swc2 \$2,0\(\$0\)'
.*:40: Error: opcode not supported on this processor: .* \(.*\) `swc2 \$3,0\(\$0\)'
.*:41: Error: opcode not supported on this processor: .* \(.*\) `swc2 \$4,0\(\$0\)'
.*:42: Error: opcode not supported on this processor: .* \(.*\) `swc2 \$5,0\(\$0\)'
.*:43: Error: opcode not supported on this processor: .* \(.*\) `swc2 \$6,0\(\$0\)'
.*:44: Error: opcode not supported on this processor: .* \(.*\) `swc2 \$7,0\(\$0\)'
.*:45: Error: opcode not supported on this processor: .* \(.*\) `swc2 \$8,0\(\$0\)'
.*:46: Error: opcode not supported on this processor: .* \(.*\) `swc2 \$9,0\(\$0\)'
.*:47: Error: opcode not supported on this processor: .* \(.*\) `swc2 \$10,0\(\$0\)'
.*:48: Error: opcode not supported on this processor: .* \(.*\) `swc2 \$11,0\(\$0\)'
.*:49: Error: opcode not supported on this processor: .* \(.*\) `swc2 \$12,0\(\$0\)'
.*:50: Error: opcode not supported on this processor: .* \(.*\) `swc2 \$13,0\(\$0\)'
.*:51: Error: opcode not supported on this processor: .* \(.*\) `swc2 \$14,0\(\$0\)'
.*:52: Error: opcode not supported on this processor: .* \(.*\) `swc2 \$15,0\(\$0\)'
.*:53: Error: opcode not supported on this processor: .* \(.*\) `swc2 \$16,0\(\$0\)'
.*:54: Error: opcode not supported on this processor: .* \(.*\) `swc2 \$17,0\(\$0\)'
.*:55: Error: opcode not supported on this processor: .* \(.*\) `swc2 \$18,0\(\$0\)'
.*:56: Error: opcode not supported on this processor: .* \(.*\) `swc2 \$19,0\(\$0\)'
.*:57: Error: opcode not supported on this processor: .* \(.*\) `swc2 \$20,0\(\$0\)'
.*:58: Error: opcode not supported on this processor: .* \(.*\) `swc2 \$21,0\(\$0\)'
.*:59: Error: opcode not supported on this processor: .* \(.*\) `swc2 \$22,0\(\$0\)'
.*:60: Error: opcode not supported on this processor: .* \(.*\) `swc2 \$23,0\(\$0\)'
.*:61: Error: opcode not supported on this processor: .* \(.*\) `swc2 \$24,0\(\$0\)'
.*:62: Error: opcode not supported on this processor: .* \(.*\) `swc2 \$25,0\(\$0\)'
.*:63: Error: opcode not supported on this processor: .* \(.*\) `swc2 \$26,0\(\$0\)'
.*:64: Error: opcode not supported on this processor: .* \(.*\) `swc2 \$27,0\(\$0\)'
.*:65: Error: opcode not supported on this processor: .* \(.*\) `swc2 \$28,0\(\$0\)'
.*:66: Error: opcode not supported on this processor: .* \(.*\) `swc2 \$29,0\(\$0\)'
.*:67: Error: opcode not supported on this processor: .* \(.*\) `swc2 \$30,0\(\$0\)'
.*:68: Error: opcode not supported on this processor: .* \(.*\) `swc2 \$31,0\(\$0\)'
