#objdump: -d
#name:    
#source:  ld-imm-page2.s


.*:     file format elf32-s12z


Disassembly of section .text:

00000000 <.text>:
   0:	1b 03 aa bb 	ld s, #-5588020
   4:	cc 
   5:	1b 03 00 30 	ld s, #12309
   9:	15 
