[^:]*: Assembler messages:
.*: Error: selected processor does not support system register name 'mpuir_el1'
.*: Error: selected processor does not support system register name 'mpuir_el2'
.*: Error: selected processor does not support system register name 'prbar_el1'
.*: Error: selected processor does not support system register name 'prbar_el1'
.*: Error: selected processor does not support system register name 'prbar_el2'
.*: Error: selected processor does not support system register name 'prbar_el2'
.*: Error: selected processor does not support system register name 'prbar1_el1'
.*: Error: selected processor does not support system register name 'prbar1_el1'
.*: Error: selected processor does not support system register name 'prbar2_el1'
.*: Error: selected processor does not support system register name 'prbar2_el1'
.*: Error: selected processor does not support system register name 'prbar3_el1'
.*: Error: selected processor does not support system register name 'prbar3_el1'
.*: Error: selected processor does not support system register name 'prbar4_el1'
.*: Error: selected processor does not support system register name 'prbar4_el1'
.*: Error: selected processor does not support system register name 'prbar5_el1'
.*: Error: selected processor does not support system register name 'prbar5_el1'
.*: Error: selected processor does not support system register name 'prbar6_el1'
.*: Error: selected processor does not support system register name 'prbar6_el1'
.*: Error: selected processor does not support system register name 'prbar7_el1'
.*: Error: selected processor does not support system register name 'prbar7_el1'
.*: Error: selected processor does not support system register name 'prbar8_el1'
.*: Error: selected processor does not support system register name 'prbar8_el1'
.*: Error: selected processor does not support system register name 'prbar9_el1'
.*: Error: selected processor does not support system register name 'prbar9_el1'
.*: Error: selected processor does not support system register name 'prbar10_el1'
.*: Error: selected processor does not support system register name 'prbar10_el1'
.*: Error: selected processor does not support system register name 'prbar11_el1'
.*: Error: selected processor does not support system register name 'prbar11_el1'
.*: Error: selected processor does not support system register name 'prbar12_el1'
.*: Error: selected processor does not support system register name 'prbar12_el1'
.*: Error: selected processor does not support system register name 'prbar13_el1'
.*: Error: selected processor does not support system register name 'prbar13_el1'
.*: Error: selected processor does not support system register name 'prbar14_el1'
.*: Error: selected processor does not support system register name 'prbar14_el1'
.*: Error: selected processor does not support system register name 'prbar15_el1'
.*: Error: selected processor does not support system register name 'prbar15_el1'
.*: Error: selected processor does not support system register name 'prbar1_el2'
.*: Error: selected processor does not support system register name 'prbar1_el2'
.*: Error: selected processor does not support system register name 'prbar2_el2'
.*: Error: selected processor does not support system register name 'prbar2_el2'
.*: Error: selected processor does not support system register name 'prbar3_el2'
.*: Error: selected processor does not support system register name 'prbar3_el2'
.*: Error: selected processor does not support system register name 'prbar4_el2'
.*: Error: selected processor does not support system register name 'prbar4_el2'
.*: Error: selected processor does not support system register name 'prbar5_el2'
.*: Error: selected processor does not support system register name 'prbar5_el2'
.*: Error: selected processor does not support system register name 'prbar6_el2'
.*: Error: selected processor does not support system register name 'prbar6_el2'
.*: Error: selected processor does not support system register name 'prbar7_el2'
.*: Error: selected processor does not support system register name 'prbar7_el2'
.*: Error: selected processor does not support system register name 'prbar8_el2'
.*: Error: selected processor does not support system register name 'prbar8_el2'
.*: Error: selected processor does not support system register name 'prbar9_el2'
.*: Error: selected processor does not support system register name 'prbar9_el2'
.*: Error: selected processor does not support system register name 'prbar10_el2'
.*: Error: selected processor does not support system register name 'prbar10_el2'
.*: Error: selected processor does not support system register name 'prbar11_el2'
.*: Error: selected processor does not support system register name 'prbar11_el2'
.*: Error: selected processor does not support system register name 'prbar12_el2'
.*: Error: selected processor does not support system register name 'prbar12_el2'
.*: Error: selected processor does not support system register name 'prbar13_el2'
.*: Error: selected processor does not support system register name 'prbar13_el2'
.*: Error: selected processor does not support system register name 'prbar14_el2'
.*: Error: selected processor does not support system register name 'prbar14_el2'
.*: Error: selected processor does not support system register name 'prbar15_el2'
.*: Error: selected processor does not support system register name 'prbar15_el2'
.*: Error: selected processor does not support system register name 'prenr_el1'
.*: Error: selected processor does not support system register name 'prenr_el1'
.*: Error: selected processor does not support system register name 'prenr_el2'
.*: Error: selected processor does not support system register name 'prenr_el2'
.*: Error: selected processor does not support system register name 'prlar_el1'
.*: Error: selected processor does not support system register name 'prlar_el1'
.*: Error: selected processor does not support system register name 'prlar_el2'
.*: Error: selected processor does not support system register name 'prlar_el2'
.*: Error: selected processor does not support system register name 'prlar1_el1'
.*: Error: selected processor does not support system register name 'prlar1_el1'
.*: Error: selected processor does not support system register name 'prlar2_el1'
.*: Error: selected processor does not support system register name 'prlar2_el1'
.*: Error: selected processor does not support system register name 'prlar3_el1'
.*: Error: selected processor does not support system register name 'prlar3_el1'
.*: Error: selected processor does not support system register name 'prlar4_el1'
.*: Error: selected processor does not support system register name 'prlar4_el1'
.*: Error: selected processor does not support system register name 'prlar5_el1'
.*: Error: selected processor does not support system register name 'prlar5_el1'
.*: Error: selected processor does not support system register name 'prlar6_el1'
.*: Error: selected processor does not support system register name 'prlar6_el1'
.*: Error: selected processor does not support system register name 'prlar7_el1'
.*: Error: selected processor does not support system register name 'prlar7_el1'
.*: Error: selected processor does not support system register name 'prlar8_el1'
.*: Error: selected processor does not support system register name 'prlar8_el1'
.*: Error: selected processor does not support system register name 'prlar9_el1'
.*: Error: selected processor does not support system register name 'prlar9_el1'
.*: Error: selected processor does not support system register name 'prlar10_el1'
.*: Error: selected processor does not support system register name 'prlar10_el1'
.*: Error: selected processor does not support system register name 'prlar11_el1'
.*: Error: selected processor does not support system register name 'prlar11_el1'
.*: Error: selected processor does not support system register name 'prlar12_el1'
.*: Error: selected processor does not support system register name 'prlar12_el1'
.*: Error: selected processor does not support system register name 'prlar13_el1'
.*: Error: selected processor does not support system register name 'prlar13_el1'
.*: Error: selected processor does not support system register name 'prlar14_el1'
.*: Error: selected processor does not support system register name 'prlar14_el1'
.*: Error: selected processor does not support system register name 'prlar15_el1'
.*: Error: selected processor does not support system register name 'prlar15_el1'
.*: Error: selected processor does not support system register name 'prlar1_el2'
.*: Error: selected processor does not support system register name 'prlar1_el2'
.*: Error: selected processor does not support system register name 'prlar2_el2'
.*: Error: selected processor does not support system register name 'prlar2_el2'
.*: Error: selected processor does not support system register name 'prlar3_el2'
.*: Error: selected processor does not support system register name 'prlar3_el2'
.*: Error: selected processor does not support system register name 'prlar4_el2'
.*: Error: selected processor does not support system register name 'prlar4_el2'
.*: Error: selected processor does not support system register name 'prlar5_el2'
.*: Error: selected processor does not support system register name 'prlar5_el2'
.*: Error: selected processor does not support system register name 'prlar6_el2'
.*: Error: selected processor does not support system register name 'prlar6_el2'
.*: Error: selected processor does not support system register name 'prlar7_el2'
.*: Error: selected processor does not support system register name 'prlar7_el2'
.*: Error: selected processor does not support system register name 'prlar8_el2'
.*: Error: selected processor does not support system register name 'prlar8_el2'
.*: Error: selected processor does not support system register name 'prlar9_el2'
.*: Error: selected processor does not support system register name 'prlar9_el2'
.*: Error: selected processor does not support system register name 'prlar10_el2'
.*: Error: selected processor does not support system register name 'prlar10_el2'
.*: Error: selected processor does not support system register name 'prlar11_el2'
.*: Error: selected processor does not support system register name 'prlar11_el2'
.*: Error: selected processor does not support system register name 'prlar12_el2'
.*: Error: selected processor does not support system register name 'prlar12_el2'
.*: Error: selected processor does not support system register name 'prlar13_el2'
.*: Error: selected processor does not support system register name 'prlar13_el2'
.*: Error: selected processor does not support system register name 'prlar14_el2'
.*: Error: selected processor does not support system register name 'prlar14_el2'
.*: Error: selected processor does not support system register name 'prlar15_el2'
.*: Error: selected processor does not support system register name 'prlar15_el2'
.*: Error: selected processor does not support system register name 'prselr_el1'
.*: Error: selected processor does not support system register name 'prselr_el1'
.*: Error: selected processor does not support system register name 'prselr_el2'
.*: Error: selected processor does not support system register name 'prselr_el2'
.*: Error: selected processor does not support system register name 'vsctlr_el2'
.*: Error: selected processor does not support system register name 'vsctlr_el2'
