.syntax unified
.text
itt ne
vcvtne.s32.f64	s13, d8
vcvtne.u32.f64	s13, d8
itt ne
vcvtne.s32.f32	s13, s8
vcvtne.u32.f32	s13, s8
itt ne
vcvtne.s32.f16	s13, s8
vcvtne.u32.f16	s13, s8
itt ne
vcvtne.f64.s32	d13, s8
vcvtne.f64.u32	d13, s8
itt ne
vcvtne.f32.s32	s13, s8
vcvtne.f32.u32	s13, s8
itt ne
vcvtne.f16.s32	s13, s8
vcvtne.f16.u32	s13, s8
