# objdump: -dr
# as: -linkrelax
# source: hex.s
.*:     file format elf64-mmix

Disassembly of section \.text:

0000000000000000 <Main>:
   0:	e3362009 	setl \$54,0x2009
   4:	e320125e 	setl \$32,0x125e
   8:	e31f00b1 	setl \$31,0xb1
