    .section .init_array.101,"aw"
    .byte 0x01

    .section .init_array.103,"aw"
    .byte 0x04

    .section .init_array,"aw"
    .byte 0x00

    .section .init_array.0103,"aw"
    .byte 0x03

    .section .fini_array.101,"aw"
    .byte 0xf1

    .section .fini_array.103,"aw"
    .byte 0xf4

    .section .fini_array,"aw"
    .byte 0xf0

    .section .fini_array.0103,"aw"
    .byte 0xf3

    .section .ctors.101,"aw"
    .byte 0xc1

    .section .ctors.103, "aw"
    .byte 0xc4

    .section .ctors,"aw"
    .byte 0xc0

    .section .ctors.0103,"aw"
    .byte 0xc3

    .section .dtors.101,"aw"
    .byte 0xd1

    .section .dtors.103,"aw"
    .byte 0xd4

    .section .dtors,"aw"
    .byte 0xd0

    .section .dtors.0103,"aw"
    .byte 0xd3

    .section .sec.101,"aw"
    .byte 0xa1

    .section .sec.103,"aw"
    .byte 0xa4

    .section .sec,"aw"
    .byte 0xa0

    .section .sec.0103,"aw"
    .byte 0xa3
