#as: -a64
#source: xcoff-dwsect-2.s
#objdump: -t
#name: XCOFF dwsect test 2 (64-bit)

.*

SYMBOL TABLE:
.*\(scl 103\).*
File .*
.*\(scl 112\).* .dwinfo
AUX .*
.*\(scl 112\).* .dwloc
AUX .*
.*\(scl 112\).* .dwarnge
AUX .*
.*\(scl 107\).* .text
.*
