#objdump: -dr

.*

Disassembly of section \.text:

0+ <\.text>:
[^:]*:	d54e97a0 	tlbip	vale3nxs, x0, x1
[^:]*:	d54e97a0 	tlbip	vale3nxs, x0, x1
[^:]*:	d54e97a2 	tlbip	vale3nxs, x2, x3
[^:]*:	d54e97a2 	tlbip	vale3nxs, x2, x3
[^:]*:	d54e97bf 	tlbip	vale3nxs, xzr
[^:]*:	d54e97a0 	tlbip	vale3nxs, x0, x1
[^:]*:	d54e97a0 	tlbip	vale3nxs, x0, x1
[^:]*:	d54e97a2 	tlbip	vale3nxs, x2, x3
[^:]*:	d54e97a2 	tlbip	vale3nxs, x2, x3
