.*: Assembler messages:
.*:5: Error: unsupported broadcast for `vcvtpd2ph'
.*:6: Error: unsupported broadcast for `vcvtuqq2ph'
.*:7: Error: unsupported broadcast for `vcvtdq2ph'
.*:8: Error: unsupported broadcast for `vcvtudq2ph'
.*:9: Error: unsupported broadcast for `vcmpph'
.*:10: Error: Unsupported broadcast: `\{1to64\}'
.*:11: Error: unsupported broadcast for `vfmadd132ph'
.*:12: Error: unsupported broadcast for `vfcmaddcph'
.*:13: Error: unsupported broadcast for `vfcmulcph'
.*:14: Error: unsupported broadcast for `vcvtdq2ph'
.*:15: Error: unsupported broadcast for `vfmaddcph'
.*:16: Error: unsupported broadcast for `vfmulcph'
.*:17: Error: unsupported broadcast for `vfmulcph'
.*:20: Error: unsupported broadcast for `vcvtpd2ph'
.*:21: Error: unsupported broadcast for `vcvtuqq2ph'
.*:22: Error: unsupported broadcast for `vcvtdq2ph'
.*:23: Error: unsupported broadcast for `vcvtudq2ph'
.*:24: Error: unsupported broadcast for `vcmpph'
.*:25: Error: Unsupported broadcast: `\{1to64\}'
.*:26: Error: unsupported broadcast for `vfmsubadd231ph'
.*:27: Error: unsupported broadcast for `vfcmaddcph'
.*:28: Error: unsupported broadcast for `vfcmulcph'
.*:29: Error: unsupported broadcast for `vcvtdq2ph'
.*:30: Error: unsupported broadcast for `vfcmaddcph'
.*:31: Error: unsupported broadcast for `vfmulcph'
.*:32: Error: unsupported broadcast for `vfmulcph'
