.mspabi_attribute 4, 2 ; OFBA_MSPABI_Tag_ISA == 430x
.mspabi_attribute 6, 2 ; OFBA_MSPABI_Tag_Code_Model == Large
.mspabi_attribute 8, 2 ; OFBA_MSPABI_Tag_Data_Model == Large
.gnu_attribute 4, 1 ; Tag_GNU_MSP430_Data_Region == Lower
