	.arch armv8-m.main
	.file	"cmse_main.c"
	.text
.Ltext0:
	.cfi_sections	.debug_frame
	.section	.text.main,"ax",%progbits
	.align	1
	.global	main
	.arch armv8-m.main
	.syntax unified
	.thumb
	.thumb_func
	.fpu fpv5-sp-d16
	.type	main, %function
main:
.LFB0:
	.file 1 "cmse_main.c"
	.loc 1 2 1
	.cfi_startproc
	.cfi_endproc
.LFE0:
