.*: Assembler messages:
.*: Error: illegal operands `th.flrd a0,a1,a2,0'
.*: Error: improper immediate value \(-?\d+\)
.*: Error: improper immediate value \(4\)
.*: Error: improper immediate value \(-?\d+\)
.*: Error: improper immediate value \(4\)
.*: Error: improper immediate value \(-?\d+\)
.*: Error: improper immediate value \(4\)
.*: Error: improper immediate value \(-?\d+\)
.*: Error: improper immediate value \(4\)
.*: Error: improper immediate value \(-?\d+\)
.*: Error: improper immediate value \(4\)
.*: Error: improper immediate value \(-?\d+\)
.*: Error: improper immediate value \(4\)
.*: Error: improper immediate value \(-?\d+\)
.*: Error: improper immediate value \(4\)
.*: Error: improper immediate value \(-?\d+\)
.*: Error: improper immediate value \(4\)

