.*: Assembler messages:
.*: Error: selected processor does not support `addpt z0.d,p0/m,z0.d,z0.d'
.*: Error: selected processor does not support `subpt z0.d,p0/m,z0.d,z0.d'
.*: Error: selected processor does not support `addpt z0.d,z0.d,z0.d'
.*: Error: selected processor does not support `subpt z0.d,z0.d,z0.d'
.*: Error: selected processor does not support `madpt z0.d,z0.d,z0.d'
.*: Error: selected processor does not support `mlapt z0.d,z0.d,z0.d'
