.*: Assembler messages:
.*: Error: illegal operands `th.ldd a0,a1,\(a2\),0'
.*: Error: illegal operands `th.lwd a0,a1,\(a2\),1'
.*: Error: illegal operands `th.lwud a0,a1,\(a2\),2'
.*: Error: illegal operands `th.sdd a0,a1,\(a2\),3'
.*: Error: illegal operands `th.swd a0,a1,\(a2\),0'

.*: Error: improper immediate value \(-?\d+\)
.*: Error: improper immediate value \(4\)
.*: Error: unexpected literal \(3\)

.*: Error: improper immediate value \(-?\d+\)
.*: Error: improper immediate value \(4\)
.*: Error: unexpected literal \(4\)

.*: Error: improper immediate value \(-?\d+\)
.*: Error: improper immediate value \(4\)
.*: Error: unexpected literal \(4\)

.*: Error: improper immediate value \(-?\d+\)
.*: Error: improper immediate value \(4\)
.*: Error: unexpected literal \(3\)

.*: Error: improper immediate value \(-?\d+\)
.*: Error: improper immediate value \(4\)
.*: Error: unexpected literal \(4\)

.*: Error: illegal operands `th.ldd a0,a0,\(a1\),0'
.*: Error: illegal operands `th.ldd a0,a1,\(a0\),0'
.*: Error: illegal operands `th.ldd a1,a0,\(a0\),0'
