# Check XOP instructions (maxcombos=16, maxops=3, archbits=64, seed=1)

	.text
_start:

# Tests for op VFRCZPD xmm2/mem128, xmm1  (at&t syntax)
    VFRCZPD        %xmm2,%xmm15
    VFRCZPD        %xmm0,%xmm12
    VFRCZPD        (%r12),%xmm0
    VFRCZPD        (%rax),%xmm15
    VFRCZPD        %xmm0,%xmm0
    VFRCZPD        (%r10),%xmm15
    VFRCZPD        %xmm2,%xmm0
    VFRCZPD        %xmm15,%xmm12
    VFRCZPD        %xmm15,%xmm0
    VFRCZPD        %xmm0,%xmm15
    VFRCZPD        (%r10),%xmm12
    VFRCZPD        %xmm15,%xmm15
    VFRCZPD        (%rax),%xmm0
    VFRCZPD        (%r12),%xmm15
    VFRCZPD        (%rax),%xmm12
    VFRCZPD        (%r10),%xmm0
# Tests for op VFRCZPD ymm2/mem256, ymm1  (at&t syntax)
    VFRCZPD        %ymm2,%ymm15
    VFRCZPD        %ymm0,%ymm12
    VFRCZPD        (%r12),%ymm0
    VFRCZPD        (%rax),%ymm15
    VFRCZPD        %ymm0,%ymm0
    VFRCZPD        (%r10),%ymm15
    VFRCZPD        %ymm2,%ymm0
    VFRCZPD        %ymm15,%ymm12
    VFRCZPD        %ymm15,%ymm0
    VFRCZPD        %ymm0,%ymm15
    VFRCZPD        (%r10),%ymm12
    VFRCZPD        %ymm15,%ymm15
    VFRCZPD        (%rax),%ymm0
    VFRCZPD        (%r12),%ymm15
    VFRCZPD        (%rax),%ymm12
    VFRCZPD        (%r10),%ymm0
# Tests for op VFRCZPS xmm2/mem128, xmm1  (at&t syntax)
    VFRCZPS        %xmm2,%xmm15
    VFRCZPS        %xmm0,%xmm12
    VFRCZPS        (%r12),%xmm0
    VFRCZPS        (%rax),%xmm15
    VFRCZPS        %xmm0,%xmm0
    VFRCZPS        (%r10),%xmm15
    VFRCZPS        %xmm2,%xmm0
    VFRCZPS        %xmm15,%xmm12
    VFRCZPS        %xmm15,%xmm0
    VFRCZPS        %xmm0,%xmm15
    VFRCZPS        (%r10),%xmm12
    VFRCZPS        %xmm15,%xmm15
    VFRCZPS        (%rax),%xmm0
    VFRCZPS        (%r12),%xmm15
    VFRCZPS        (%rax),%xmm12
    VFRCZPS        (%r10),%xmm0
# Tests for op VFRCZPS ymm2/mem256, ymm1  (at&t syntax)
    VFRCZPS        %ymm2,%ymm15
    VFRCZPS        %ymm0,%ymm12
    VFRCZPS        (%r12),%ymm0
    VFRCZPS        (%rax),%ymm15
    VFRCZPS        %ymm0,%ymm0
    VFRCZPS        (%r10),%ymm15
    VFRCZPS        %ymm2,%ymm0
    VFRCZPS        %ymm15,%ymm12
    VFRCZPS        %ymm15,%ymm0
    VFRCZPS        %ymm0,%ymm15
    VFRCZPS        (%r10),%ymm12
    VFRCZPS        %ymm15,%ymm15
    VFRCZPS        (%rax),%ymm0
    VFRCZPS        (%r12),%ymm15
    VFRCZPS        (%rax),%ymm12
    VFRCZPS        (%r10),%ymm0
# Tests for op VFRCZSD xmm2/mem64, xmm1  (at&t syntax)
    VFRCZSD        %xmm2,%xmm15
    VFRCZSD        %xmm0,%xmm12
    VFRCZSD        (%r12),%xmm0
    VFRCZSD        (%rax),%xmm15
    VFRCZSD        %xmm0,%xmm0
    VFRCZSD        (%r10),%xmm15
    VFRCZSD        %xmm2,%xmm0
    VFRCZSD        %xmm15,%xmm12
    VFRCZSD        %xmm15,%xmm0
    VFRCZSD        %xmm0,%xmm15
    VFRCZSD        (%r10),%xmm12
    VFRCZSD        %xmm15,%xmm15
    VFRCZSD        (%rax),%xmm0
    VFRCZSD        (%r12),%xmm15
    VFRCZSD        (%rax),%xmm12
    VFRCZSD        (%r10),%xmm0
# Tests for op VFRCZSS xmm2/mem32, xmm1  (at&t syntax)
    VFRCZSS        %xmm2,%xmm15
    VFRCZSS        %xmm0,%xmm12
    VFRCZSS        (%r12),%xmm0
    VFRCZSS        (%rax),%xmm15
    VFRCZSS        %xmm0,%xmm0
    VFRCZSS        (%r10),%xmm15
    VFRCZSS        %xmm2,%xmm0
    VFRCZSS        %xmm15,%xmm12
    VFRCZSS        %xmm15,%xmm0
    VFRCZSS        %xmm0,%xmm15
    VFRCZSS        (%r10),%xmm12
    VFRCZSS        %xmm15,%xmm15
    VFRCZSS        (%rax),%xmm0
    VFRCZSS        (%r12),%xmm15
    VFRCZSS        (%rax),%xmm12
    VFRCZSS        (%r10),%xmm0
# Tests for op VPCMOV xmm4, xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPCMOV         %xmm0,%xmm15,%xmm7,%xmm0
    VPCMOV         %xmm2,(%r9),%xmm0,%xmm0
    VPCMOV         %xmm15,(%r9),%xmm15,%xmm0
    VPCMOV         %xmm15,%xmm0,%xmm0,%xmm11
    VPCMOV         %xmm15,%xmm12,%xmm0,%xmm0
    VPCMOV         %xmm15,%xmm12,%xmm0,%xmm15
    VPCMOV         %xmm15,(%r12),%xmm0,%xmm15
    VPCMOV         %xmm2,%xmm0,%xmm0,%xmm15
    VPCMOV         %xmm2,(%r9),%xmm15,%xmm15
    VPCMOV         %xmm2,%xmm12,%xmm15,%xmm15
    VPCMOV         %xmm2,(%r12),%xmm15,%xmm0
    VPCMOV         %xmm0,(%r13),%xmm15,%xmm0
    VPCMOV         %xmm15,(%r13),%xmm7,%xmm11
    VPCMOV         %xmm15,(%r12),%xmm7,%xmm11
    VPCMOV         %xmm15,%xmm15,%xmm0,%xmm0
    VPCMOV         %xmm2,(%r9),%xmm15,%xmm11
# Tests for op VPCMOV ymm4, ymm3/mem256, ymm2, ymm1  (at&t syntax)
    VPCMOV         %ymm0,%ymm15,%ymm7,%ymm0
    VPCMOV         %ymm2,(%r9),%ymm0,%ymm0
    VPCMOV         %ymm15,(%r9),%ymm15,%ymm0
    VPCMOV         %ymm15,%ymm0,%ymm0,%ymm11
    VPCMOV         %ymm15,%ymm12,%ymm0,%ymm0
    VPCMOV         %ymm15,%ymm12,%ymm0,%ymm15
    VPCMOV         %ymm15,(%r12),%ymm0,%ymm15
    VPCMOV         %ymm2,%ymm0,%ymm0,%ymm15
    VPCMOV         %ymm2,(%r9),%ymm15,%ymm15
    VPCMOV         %ymm2,%ymm12,%ymm15,%ymm15
    VPCMOV         %ymm2,(%r12),%ymm15,%ymm0
    VPCMOV         %ymm0,(%r13),%ymm15,%ymm0
    VPCMOV         %ymm15,(%r13),%ymm7,%ymm11
    VPCMOV         %ymm15,(%r12),%ymm7,%ymm11
    VPCMOV         %ymm15,%ymm15,%ymm0,%ymm0
    VPCMOV         %ymm2,(%r9),%ymm15,%ymm11
# Tests for op VPCMOV xmm4/mem128, xmm3, xmm2, xmm1  (at&t syntax)
    VPCMOV         %xmm0,%xmm12,%xmm7,%xmm0
    VPCMOV         (%rax),%xmm15,%xmm0,%xmm0
    VPCMOV         (%r10),%xmm15,%xmm15,%xmm0
    VPCMOV         %xmm2,%xmm0,%xmm0,%xmm11
    VPCMOV         %xmm2,%xmm0,%xmm0,%xmm0
    VPCMOV         %xmm2,%xmm0,%xmm0,%xmm15
    VPCMOV         (%r10),%xmm12,%xmm0,%xmm15
    VPCMOV         (%rax),%xmm0,%xmm0,%xmm15
    VPCMOV         (%r12),%xmm15,%xmm15,%xmm15
    VPCMOV         (%r12),%xmm0,%xmm15,%xmm15
    VPCMOV         (%rax),%xmm12,%xmm15,%xmm0
    VPCMOV         %xmm15,%xmm15,%xmm15,%xmm0
    VPCMOV         (%r10),%xmm15,%xmm7,%xmm11
    VPCMOV         %xmm2,%xmm12,%xmm7,%xmm11
    VPCMOV         %xmm2,%xmm12,%xmm0,%xmm0
    VPCMOV         (%r12),%xmm15,%xmm15,%xmm11
# Tests for op VPCMOV ymm4/mem256, ymm3, ymm2, ymm1  (at&t syntax)
    VPCMOV         %ymm0,%ymm12,%ymm7,%ymm0
    VPCMOV         (%rax),%ymm15,%ymm0,%ymm0
    VPCMOV         (%r10),%ymm15,%ymm15,%ymm0
    VPCMOV         %ymm2,%ymm0,%ymm0,%ymm11
    VPCMOV         %ymm2,%ymm0,%ymm0,%ymm0
    VPCMOV         %ymm2,%ymm0,%ymm0,%ymm15
    VPCMOV         (%r10),%ymm12,%ymm0,%ymm15
    VPCMOV         (%rax),%ymm0,%ymm0,%ymm15
    VPCMOV         (%r12),%ymm15,%ymm15,%ymm15
    VPCMOV         (%r12),%ymm0,%ymm15,%ymm15
    VPCMOV         (%rax),%ymm12,%ymm15,%ymm0
    VPCMOV         %ymm15,%ymm15,%ymm15,%ymm0
    VPCMOV         (%r10),%ymm15,%ymm7,%ymm11
    VPCMOV         %ymm2,%ymm12,%ymm7,%ymm11
    VPCMOV         %ymm2,%ymm12,%ymm0,%ymm0
    VPCMOV         (%r12),%ymm15,%ymm15,%ymm11
# Tests for op VPCOMB imm8, xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPCOMB         $0x3,(%rdi),%xmm0,%xmm15
    VPCOMB         $0xFF,%xmm0,%xmm0,%xmm1
    VPCOMB         $0xFF,%xmm15,%xmm0,%xmm1
    VPCOMB         $0x0,%xmm11,%xmm11,%xmm1
    VPCOMB         $0x0,%xmm11,%xmm0,%xmm1
    VPCOMB         $0x0,%xmm0,%xmm15,%xmm1
    VPCOMB         $0x3,%xmm11,%xmm15,%xmm15
    VPCOMB         $0x0,%xmm11,%xmm15,%xmm15
    VPCOMB         $0xFF,%xmm15,%xmm15,%xmm15
    VPCOMB         $0x0,(%rcx),%xmm15,%xmm15
    VPCOMB         $0x3,(%rcx),%xmm0,%xmm0
    VPCOMB         $0xFF,(%rdi),%xmm11,%xmm1
    VPCOMB         $0x3,(%rdi),%xmm11,%xmm1
    VPCOMB         $0x3,%xmm0,%xmm0,%xmm15
    VPCOMB         $0xFF,(%rcx),%xmm11,%xmm0
    VPCOMB         $0x3,(%rsi),%xmm15,%xmm1
# Tests for op VPCOMD imm8, xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPCOMD         $0x3,(%rdi),%xmm0,%xmm15
    VPCOMD         $0xFF,%xmm0,%xmm0,%xmm1
    VPCOMD         $0xFF,%xmm15,%xmm0,%xmm1
    VPCOMD         $0x0,%xmm11,%xmm11,%xmm1
    VPCOMD         $0x0,%xmm11,%xmm0,%xmm1
    VPCOMD         $0x0,%xmm0,%xmm15,%xmm1
    VPCOMD         $0x3,%xmm11,%xmm15,%xmm15
    VPCOMD         $0x0,%xmm11,%xmm15,%xmm15
    VPCOMD         $0xFF,%xmm15,%xmm15,%xmm15
    VPCOMD         $0x0,(%rcx),%xmm15,%xmm15
    VPCOMD         $0x3,(%rcx),%xmm0,%xmm0
    VPCOMD         $0xFF,(%rdi),%xmm11,%xmm1
    VPCOMD         $0x3,(%rdi),%xmm11,%xmm1
    VPCOMD         $0x3,%xmm0,%xmm0,%xmm15
    VPCOMD         $0xFF,(%rcx),%xmm11,%xmm0
    VPCOMD         $0x3,(%rsi),%xmm15,%xmm1
# Tests for op VPCOMQ imm8, xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPCOMQ         $0x3,(%rdi),%xmm0,%xmm15
    VPCOMQ         $0xFF,%xmm0,%xmm0,%xmm1
    VPCOMQ         $0xFF,%xmm15,%xmm0,%xmm1
    VPCOMQ         $0x0,%xmm11,%xmm11,%xmm1
    VPCOMQ         $0x0,%xmm11,%xmm0,%xmm1
    VPCOMQ         $0x0,%xmm0,%xmm15,%xmm1
    VPCOMQ         $0x3,%xmm11,%xmm15,%xmm15
    VPCOMQ         $0x0,%xmm11,%xmm15,%xmm15
    VPCOMQ         $0xFF,%xmm15,%xmm15,%xmm15
    VPCOMQ         $0x0,(%rcx),%xmm15,%xmm15
    VPCOMQ         $0x3,(%rcx),%xmm0,%xmm0
    VPCOMQ         $0xFF,(%rdi),%xmm11,%xmm1
    VPCOMQ         $0x3,(%rdi),%xmm11,%xmm1
    VPCOMQ         $0x3,%xmm0,%xmm0,%xmm15
    VPCOMQ         $0xFF,(%rcx),%xmm11,%xmm0
    VPCOMQ         $0x3,(%rsi),%xmm15,%xmm1
# Tests for op VPCOMUB imm8, xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPCOMUB        $0x3,(%rdi),%xmm0,%xmm15
    VPCOMUB        $0xFF,%xmm0,%xmm0,%xmm1
    VPCOMUB        $0xFF,%xmm15,%xmm0,%xmm1
    VPCOMUB        $0x0,%xmm11,%xmm11,%xmm1
    VPCOMUB        $0x0,%xmm11,%xmm0,%xmm1
    VPCOMUB        $0x0,%xmm0,%xmm15,%xmm1
    VPCOMUB        $0x3,%xmm11,%xmm15,%xmm15
    VPCOMUB        $0x0,%xmm11,%xmm15,%xmm15
    VPCOMUB        $0xFF,%xmm15,%xmm15,%xmm15
    VPCOMUB        $0x0,(%rcx),%xmm15,%xmm15
    VPCOMUB        $0x3,(%rcx),%xmm0,%xmm0
    VPCOMUB        $0xFF,(%rdi),%xmm11,%xmm1
    VPCOMUB        $0x3,(%rdi),%xmm11,%xmm1
    VPCOMUB        $0x3,%xmm0,%xmm0,%xmm15
    VPCOMUB        $0xFF,(%rcx),%xmm11,%xmm0
    VPCOMUB        $0x3,(%rsi),%xmm15,%xmm1
# Tests for op VPCOMUD imm8, xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPCOMUD        $0x3,(%rdi),%xmm0,%xmm15
    VPCOMUD        $0xFF,%xmm0,%xmm0,%xmm1
    VPCOMUD        $0xFF,%xmm15,%xmm0,%xmm1
    VPCOMUD        $0x0,%xmm11,%xmm11,%xmm1
    VPCOMUD        $0x0,%xmm11,%xmm0,%xmm1
    VPCOMUD        $0x0,%xmm0,%xmm15,%xmm1
    VPCOMUD        $0x3,%xmm11,%xmm15,%xmm15
    VPCOMUD        $0x0,%xmm11,%xmm15,%xmm15
    VPCOMUD        $0xFF,%xmm15,%xmm15,%xmm15
    VPCOMUD        $0x0,(%rcx),%xmm15,%xmm15
    VPCOMUD        $0x3,(%rcx),%xmm0,%xmm0
    VPCOMUD        $0xFF,(%rdi),%xmm11,%xmm1
    VPCOMUD        $0x3,(%rdi),%xmm11,%xmm1
    VPCOMUD        $0x3,%xmm0,%xmm0,%xmm15
    VPCOMUD        $0xFF,(%rcx),%xmm11,%xmm0
    VPCOMUD        $0x3,(%rsi),%xmm15,%xmm1
# Tests for op VPCOMUQ imm8, xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPCOMUQ        $0x3,(%rdi),%xmm0,%xmm15
    VPCOMUQ        $0xFF,%xmm0,%xmm0,%xmm1
    VPCOMUQ        $0xFF,%xmm15,%xmm0,%xmm1
    VPCOMUQ        $0x0,%xmm11,%xmm11,%xmm1
    VPCOMUQ        $0x0,%xmm11,%xmm0,%xmm1
    VPCOMUQ        $0x0,%xmm0,%xmm15,%xmm1
    VPCOMUQ        $0x3,%xmm11,%xmm15,%xmm15
    VPCOMUQ        $0x0,%xmm11,%xmm15,%xmm15
    VPCOMUQ        $0xFF,%xmm15,%xmm15,%xmm15
    VPCOMUQ        $0x0,(%rcx),%xmm15,%xmm15
    VPCOMUQ        $0x3,(%rcx),%xmm0,%xmm0
    VPCOMUQ        $0xFF,(%rdi),%xmm11,%xmm1
    VPCOMUQ        $0x3,(%rdi),%xmm11,%xmm1
    VPCOMUQ        $0x3,%xmm0,%xmm0,%xmm15
    VPCOMUQ        $0xFF,(%rcx),%xmm11,%xmm0
    VPCOMUQ        $0x3,(%rsi),%xmm15,%xmm1
# Tests for op VPCOMUW imm8, xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPCOMUW        $0x3,(%rdi),%xmm0,%xmm15
    VPCOMUW        $0xFF,%xmm0,%xmm0,%xmm1
    VPCOMUW        $0xFF,%xmm15,%xmm0,%xmm1
    VPCOMUW        $0x0,%xmm11,%xmm11,%xmm1
    VPCOMUW        $0x0,%xmm11,%xmm0,%xmm1
    VPCOMUW        $0x0,%xmm0,%xmm15,%xmm1
    VPCOMUW        $0x3,%xmm11,%xmm15,%xmm15
    VPCOMUW        $0x0,%xmm11,%xmm15,%xmm15
    VPCOMUW        $0xFF,%xmm15,%xmm15,%xmm15
    VPCOMUW        $0x0,(%rcx),%xmm15,%xmm15
    VPCOMUW        $0x3,(%rcx),%xmm0,%xmm0
    VPCOMUW        $0xFF,(%rdi),%xmm11,%xmm1
    VPCOMUW        $0x3,(%rdi),%xmm11,%xmm1
    VPCOMUW        $0x3,%xmm0,%xmm0,%xmm15
    VPCOMUW        $0xFF,(%rcx),%xmm11,%xmm0
    VPCOMUW        $0x3,(%rsi),%xmm15,%xmm1
# Tests for op VPCOMW imm8, xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPCOMW         $0x3,(%rdi),%xmm0,%xmm15
    VPCOMW         $0xFF,%xmm0,%xmm0,%xmm1
    VPCOMW         $0xFF,%xmm15,%xmm0,%xmm1
    VPCOMW         $0x0,%xmm11,%xmm11,%xmm1
    VPCOMW         $0x0,%xmm11,%xmm0,%xmm1
    VPCOMW         $0x0,%xmm0,%xmm15,%xmm1
    VPCOMW         $0x3,%xmm11,%xmm15,%xmm15
    VPCOMW         $0x0,%xmm11,%xmm15,%xmm15
    VPCOMW         $0xFF,%xmm15,%xmm15,%xmm15
    VPCOMW         $0x0,(%rcx),%xmm15,%xmm15
    VPCOMW         $0x3,(%rcx),%xmm0,%xmm0
    VPCOMW         $0xFF,(%rdi),%xmm11,%xmm1
    VPCOMW         $0x3,(%rdi),%xmm11,%xmm1
    VPCOMW         $0x3,%xmm0,%xmm0,%xmm15
    VPCOMW         $0xFF,(%rcx),%xmm11,%xmm0
    VPCOMW         $0x3,(%rsi),%xmm15,%xmm1
# Testing VPERMIL2PD imm8, xmm4, xmm3/mem128, xmm2, xmm1 (at&t syntax)
    VPERMIL2PD     $0x3,%xmm14,%xmm13,%xmm11,%xmm10
    VPERMIL2PD     $0x2,%xmm15,(%rdi,%r8),%xmm1,%xmm0
    VPERMIL2PD     $0x1,%xmm0,0x23(%r12,%r12,8),%xmm0,%xmm2
    VPERMIL2PD     $0x0,%xmm3,%xmm15,%xmm13,%xmm2
    VPERMIL2PD     $0x2,%xmm3,%xmm14,%xmm11,%xmm0
    VPERMIL2PD     $0x1,%xmm0,(%rdx),%xmm1,%xmm0
    VPERMIL2PD     $0x3,%xmm3,%xmm0,%xmm0,%xmm9
    VPERMIL2PD     $0x0,%xmm2,0x23(%r12,%r12,8),%xmm0,%xmm3
# Testing VPERMIL2PD imm8, xmm4/mem128, xmm3, xmm2, xmm1 (at&t syntax)
    VPERMIL2PD     $0x0,%xmm0,%xmm7,%xmm11,%xmm0
    VPERMIL2PD     $0x1,%xmm4,%xmm5,%xmm15,%xmm0
    VPERMIL2PD     $0x3,0x4(%r12,%rbx,4),%xmm8,%xmm0,%xmm10
    VPERMIL2PD     $0x2,%xmm1,%xmm0,%xmm7,%xmm6
    VPERMIL2PD     $0x1,(%r13,%rbx),%xmm12,%xmm6,%xmm10
    VPERMIL2PD     $0x2,%xmm4,%xmm6,%xmm0,%xmm9
    VPERMIL2PD     $0x0,(%rbx,%rbx,8),%xmm8,%xmm6,%xmm11
    VPERMIL2PD     $0x3,%xmm5,%xmm13,%xmm6,%xmm0
# Testing VPERMIL2PD imm8, ymm4, ymm3/mem256, ymm2, ymm1 (at&t syntax)
    VPERMIL2PD     $0x1,%ymm7,%ymm5,%ymm0,%ymm13
    VPERMIL2PD     $0x0,%ymm7,(%rcx,%r9,2),%ymm4,%ymm12
    VPERMIL2PD     $0x3,%ymm3,(%r14,%r11),%ymm0,%ymm8
    VPERMIL2PD     $0x2,%ymm7,0x107(%r9,%rax,4),%ymm0,%ymm9
    VPERMIL2PD     $0x2,%ymm7,(%r14,%r11),%ymm0,%ymm8
    VPERMIL2PD     $0x3,%ymm0,(%rcx,%r9,2),%ymm4,%ymm0
    VPERMIL2PD     $0x1,%ymm8,(%r14,%r11),%ymm11,%ymm5
    VPERMIL2PD     $0x0,%ymm2,(%rsi),%ymm0,%ymm13
# Testing VPERMIL2PD imm8, ymm4/mem256, ymm3, ymm2, ymm1 (at&t syntax)
    VPERMIL2PD     $0x1,(%rcx,%rsi),%ymm0,%ymm10,%ymm15
    VPERMIL2PD     $0x2,(%r9),%ymm12,%ymm0,%ymm0
    VPERMIL2PD     $0x0,0x15D8D9(%rcx,%r14,1),%ymm8,%ymm11,%ymm4
    VPERMIL2PD     $0x3,%ymm9,%ymm12,%ymm0,%ymm0
    VPERMIL2PD     $0x3,(%r13,%r11,1),%ymm1,%ymm14,%ymm8
    VPERMIL2PD     $0x0,0x15D8D9(%rcx,%r14,1),%ymm0,%ymm0,%ymm11
    VPERMIL2PD     $0x1,(%r13,%r11,1),%ymm1,%ymm15,%ymm0
    VPERMIL2PD     $0x2,%ymm9,%ymm13,%ymm11,%ymm5
# Testing VPERMIL2PS imm8, xmm4, xmm3/mem128, xmm2, xmm1 (at&t syntax)
    VPERMIL2PS     $0x2,%xmm0,0x23(%r12,%r12,8),%xmm0,%xmm15
    VPERMIL2PS     $0x0,%xmm0,0x23(%r12,%r12,8),%xmm3,%xmm9
    VPERMIL2PS     $0x3,%xmm0,%xmm12,%xmm7,%xmm11
    VPERMIL2PS     $0x1,%xmm3,(%rdx),%xmm0,%xmm0
    VPERMIL2PS     $0x2,%xmm3,(%r14,%r9,1),%xmm0,%xmm0
    VPERMIL2PS     $0x1,%xmm3,(%rdx),%xmm1,%xmm0
    VPERMIL2PS     $0x0,%xmm3,%xmm8,%xmm0,%xmm12
    VPERMIL2PS     $0x3,%xmm3,(%r14,%r9,1),%xmm1,%xmm2
# Testing VPERMIL2PS imm8, xmm4/mem128, xmm3, xmm2, xmm1 (at&t syntax)
    VPERMIL2PS     $0x1,(%r13,%rax),%xmm0,%xmm0,%xmm11
    VPERMIL2PS     $0x3,(%rdi),%xmm15,%xmm6,%xmm10
    VPERMIL2PS     $0x2,%xmm0,%xmm13,%xmm0,%xmm0
    VPERMIL2PS     $0x0,%xmm4,%xmm0,%xmm14,%xmm10
    VPERMIL2PS     $0x1,%xmm0,%xmm0,%xmm3,%xmm11
    VPERMIL2PS     $0x2,(%rbx,%rbx,8),%xmm11,%xmm6,%xmm10
    VPERMIL2PS     $0x3,%xmm4,%xmm5,%xmm6,%xmm15
    VPERMIL2PS     $0x0,0x4(%r12,%rbx,4),%xmm0,%xmm0,%xmm10
# Testing VPERMIL2PS imm8, ymm4, ymm3/mem256, ymm2, ymm1 (at&t syntax)
    VPERMIL2PS     $0x1,%ymm0,(%rsi),%ymm0,%ymm0
    VPERMIL2PS     $0x2,%ymm15,0x107(%r9,%rax,4),%ymm11,%ymm0
    VPERMIL2PS     $0x0,%ymm7,%ymm0,%ymm4,%ymm0
    VPERMIL2PS     $0x3,%ymm7,(%rcx,%r9,2),%ymm4,%ymm15
    VPERMIL2PS     $0x2,%ymm0,%ymm0,%ymm4,%ymm15
    VPERMIL2PS     $0x3,%ymm0,0x107(%r9,%rax,4),%ymm15,%ymm13
    VPERMIL2PS     $0x0,%ymm7,%ymm8,%ymm14,%ymm13
    VPERMIL2PS     $0x1,%ymm7,%ymm15,%ymm4,%ymm13
# Testing VPERMIL2PS imm8, ymm4/mem256, ymm3, ymm2, ymm1 (at&t syntax)
    VPERMIL2PS     $0x0,0x15D8D9(%rcx,%r14,1),%ymm0,%ymm0,%ymm15
    VPERMIL2PS     $0x3,(%r13,%r11,1),%ymm12,%ymm15,%ymm4
    VPERMIL2PS     $0x2,0x15D8D9(%rcx,%r14,1),%ymm0,%ymm0,%ymm0
    VPERMIL2PS     $0x1,%ymm0,%ymm2,%ymm3,%ymm4
    VPERMIL2PS     $0x3,(%rcx,%rsi),%ymm12,%ymm0,%ymm4
    VPERMIL2PS     $0x2,(%rcx,%rsi),%ymm1,%ymm0,%ymm4
    VPERMIL2PS     $0x0,(%r13,%r11,1),%ymm0,%ymm0,%ymm4
    VPERMIL2PS     $0x1,%ymm8,%ymm7,%ymm4,%ymm0
# Tests for op VPHADDBD xmm2/mem128, xmm1  (at&t syntax)
    VPHADDBD       %xmm2,%xmm15
    VPHADDBD       %xmm0,%xmm12
    VPHADDBD       (%r12),%xmm0
    VPHADDBD       (%rax),%xmm15
    VPHADDBD       %xmm0,%xmm0
    VPHADDBD       (%r10),%xmm15
    VPHADDBD       %xmm2,%xmm0
    VPHADDBD       %xmm15,%xmm12
    VPHADDBD       %xmm15,%xmm0
    VPHADDBD       %xmm0,%xmm15
    VPHADDBD       (%r10),%xmm12
    VPHADDBD       %xmm15,%xmm15
    VPHADDBD       (%rax),%xmm0
    VPHADDBD       (%r12),%xmm15
    VPHADDBD       (%rax),%xmm12
    VPHADDBD       (%r10),%xmm0
# Tests for op VPHADDBQ xmm2/mem128, xmm1  (at&t syntax)
    VPHADDBQ       %xmm2,%xmm15
    VPHADDBQ       %xmm0,%xmm12
    VPHADDBQ       (%r12),%xmm0
    VPHADDBQ       (%rax),%xmm15
    VPHADDBQ       %xmm0,%xmm0
    VPHADDBQ       (%r10),%xmm15
    VPHADDBQ       %xmm2,%xmm0
    VPHADDBQ       %xmm15,%xmm12
    VPHADDBQ       %xmm15,%xmm0
    VPHADDBQ       %xmm0,%xmm15
    VPHADDBQ       (%r10),%xmm12
    VPHADDBQ       %xmm15,%xmm15
    VPHADDBQ       (%rax),%xmm0
    VPHADDBQ       (%r12),%xmm15
    VPHADDBQ       (%rax),%xmm12
    VPHADDBQ       (%r10),%xmm0
# Tests for op VPHADDBW xmm2/mem128, xmm1  (at&t syntax)
    VPHADDBW       %xmm2,%xmm15
    VPHADDBW       %xmm0,%xmm12
    VPHADDBW       (%r12),%xmm0
    VPHADDBW       (%rax),%xmm15
    VPHADDBW       %xmm0,%xmm0
    VPHADDBW       (%r10),%xmm15
    VPHADDBW       %xmm2,%xmm0
    VPHADDBW       %xmm15,%xmm12
    VPHADDBW       %xmm15,%xmm0
    VPHADDBW       %xmm0,%xmm15
    VPHADDBW       (%r10),%xmm12
    VPHADDBW       %xmm15,%xmm15
    VPHADDBW       (%rax),%xmm0
    VPHADDBW       (%r12),%xmm15
    VPHADDBW       (%rax),%xmm12
    VPHADDBW       (%r10),%xmm0
# Tests for op VPHADDDQ xmm2/mem128, xmm1  (at&t syntax)
    VPHADDDQ       %xmm2,%xmm15
    VPHADDDQ       %xmm0,%xmm12
    VPHADDDQ       (%r12),%xmm0
    VPHADDDQ       (%rax),%xmm15
    VPHADDDQ       %xmm0,%xmm0
    VPHADDDQ       (%r10),%xmm15
    VPHADDDQ       %xmm2,%xmm0
    VPHADDDQ       %xmm15,%xmm12
    VPHADDDQ       %xmm15,%xmm0
    VPHADDDQ       %xmm0,%xmm15
    VPHADDDQ       (%r10),%xmm12
    VPHADDDQ       %xmm15,%xmm15
    VPHADDDQ       (%rax),%xmm0
    VPHADDDQ       (%r12),%xmm15
    VPHADDDQ       (%rax),%xmm12
    VPHADDDQ       (%r10),%xmm0
# Tests for op VPHADDUBD xmm2/mem128, xmm1  (at&t syntax)
    VPHADDUBD      %xmm2,%xmm15
    VPHADDUBD      %xmm0,%xmm12
    VPHADDUBD      (%r12),%xmm0
    VPHADDUBD      (%rax),%xmm15
    VPHADDUBD      %xmm0,%xmm0
    VPHADDUBD      (%r10),%xmm15
    VPHADDUBD      %xmm2,%xmm0
    VPHADDUBD      %xmm15,%xmm12
    VPHADDUBD      %xmm15,%xmm0
    VPHADDUBD      %xmm0,%xmm15
    VPHADDUBD      (%r10),%xmm12
    VPHADDUBD      %xmm15,%xmm15
    VPHADDUBD      (%rax),%xmm0
    VPHADDUBD      (%r12),%xmm15
    VPHADDUBD      (%rax),%xmm12
    VPHADDUBD      (%r10),%xmm0
# Tests for op VPHADDUBQ xmm2/mem128, xmm1  (at&t syntax)
    VPHADDUBQ      %xmm2,%xmm15
    VPHADDUBQ      %xmm0,%xmm12
    VPHADDUBQ      (%r12),%xmm0
    VPHADDUBQ      (%rax),%xmm15
    VPHADDUBQ      %xmm0,%xmm0
    VPHADDUBQ      (%r10),%xmm15
    VPHADDUBQ      %xmm2,%xmm0
    VPHADDUBQ      %xmm15,%xmm12
    VPHADDUBQ      %xmm15,%xmm0
    VPHADDUBQ      %xmm0,%xmm15
    VPHADDUBQ      (%r10),%xmm12
    VPHADDUBQ      %xmm15,%xmm15
    VPHADDUBQ      (%rax),%xmm0
    VPHADDUBQ      (%r12),%xmm15
    VPHADDUBQ      (%rax),%xmm12
    VPHADDUBQ      (%r10),%xmm0
# Tests for op VPHADDUBW xmm2/mem128, xmm1  (at&t syntax)
    VPHADDUBW      %xmm2,%xmm15
    VPHADDUBW      %xmm0,%xmm12
    VPHADDUBW      (%r12),%xmm0
    VPHADDUBW      (%rax),%xmm15
    VPHADDUBW      %xmm0,%xmm0
    VPHADDUBW      (%r10),%xmm15
    VPHADDUBW      %xmm2,%xmm0
    VPHADDUBW      %xmm15,%xmm12
    VPHADDUBW      %xmm15,%xmm0
    VPHADDUBW      %xmm0,%xmm15
    VPHADDUBW      (%r10),%xmm12
    VPHADDUBW      %xmm15,%xmm15
    VPHADDUBW      (%rax),%xmm0
    VPHADDUBW      (%r12),%xmm15
    VPHADDUBW      (%rax),%xmm12
    VPHADDUBW      (%r10),%xmm0
# Tests for op VPHADDUDQ xmm2/mem128, xmm1  (at&t syntax)
    VPHADDUDQ      %xmm2,%xmm15
    VPHADDUDQ      %xmm0,%xmm12
    VPHADDUDQ      (%r12),%xmm0
    VPHADDUDQ      (%rax),%xmm15
    VPHADDUDQ      %xmm0,%xmm0
    VPHADDUDQ      (%r10),%xmm15
    VPHADDUDQ      %xmm2,%xmm0
    VPHADDUDQ      %xmm15,%xmm12
    VPHADDUDQ      %xmm15,%xmm0
    VPHADDUDQ      %xmm0,%xmm15
    VPHADDUDQ      (%r10),%xmm12
    VPHADDUDQ      %xmm15,%xmm15
    VPHADDUDQ      (%rax),%xmm0
    VPHADDUDQ      (%r12),%xmm15
    VPHADDUDQ      (%rax),%xmm12
    VPHADDUDQ      (%r10),%xmm0
# Tests for op VPHADDUWD xmm2/mem128, xmm1  (at&t syntax)
    VPHADDUWD      %xmm2,%xmm15
    VPHADDUWD      %xmm0,%xmm12
    VPHADDUWD      (%r12),%xmm0
    VPHADDUWD      (%rax),%xmm15
    VPHADDUWD      %xmm0,%xmm0
    VPHADDUWD      (%r10),%xmm15
    VPHADDUWD      %xmm2,%xmm0
    VPHADDUWD      %xmm15,%xmm12
    VPHADDUWD      %xmm15,%xmm0
    VPHADDUWD      %xmm0,%xmm15
    VPHADDUWD      (%r10),%xmm12
    VPHADDUWD      %xmm15,%xmm15
    VPHADDUWD      (%rax),%xmm0
    VPHADDUWD      (%r12),%xmm15
    VPHADDUWD      (%rax),%xmm12
    VPHADDUWD      (%r10),%xmm0
# Tests for op VPHADDUWQ xmm2/mem128, xmm1  (at&t syntax)
    VPHADDUWQ      %xmm2,%xmm15
    VPHADDUWQ      %xmm0,%xmm12
    VPHADDUWQ      (%r12),%xmm0
    VPHADDUWQ      (%rax),%xmm15
    VPHADDUWQ      %xmm0,%xmm0
    VPHADDUWQ      (%r10),%xmm15
    VPHADDUWQ      %xmm2,%xmm0
    VPHADDUWQ      %xmm15,%xmm12
    VPHADDUWQ      %xmm15,%xmm0
    VPHADDUWQ      %xmm0,%xmm15
    VPHADDUWQ      (%r10),%xmm12
    VPHADDUWQ      %xmm15,%xmm15
    VPHADDUWQ      (%rax),%xmm0
    VPHADDUWQ      (%r12),%xmm15
    VPHADDUWQ      (%rax),%xmm12
    VPHADDUWQ      (%r10),%xmm0
# Tests for op VPHADDWD xmm2/mem128, xmm1  (at&t syntax)
    VPHADDWD       %xmm2,%xmm15
    VPHADDWD       %xmm0,%xmm12
    VPHADDWD       (%r12),%xmm0
    VPHADDWD       (%rax),%xmm15
    VPHADDWD       %xmm0,%xmm0
    VPHADDWD       (%r10),%xmm15
    VPHADDWD       %xmm2,%xmm0
    VPHADDWD       %xmm15,%xmm12
    VPHADDWD       %xmm15,%xmm0
    VPHADDWD       %xmm0,%xmm15
    VPHADDWD       (%r10),%xmm12
    VPHADDWD       %xmm15,%xmm15
    VPHADDWD       (%rax),%xmm0
    VPHADDWD       (%r12),%xmm15
    VPHADDWD       (%rax),%xmm12
    VPHADDWD       (%r10),%xmm0
# Tests for op VPHADDWQ xmm2/mem128, xmm1  (at&t syntax)
    VPHADDWQ       %xmm2,%xmm15
    VPHADDWQ       %xmm0,%xmm12
    VPHADDWQ       (%r12),%xmm0
    VPHADDWQ       (%rax),%xmm15
    VPHADDWQ       %xmm0,%xmm0
    VPHADDWQ       (%r10),%xmm15
    VPHADDWQ       %xmm2,%xmm0
    VPHADDWQ       %xmm15,%xmm12
    VPHADDWQ       %xmm15,%xmm0
    VPHADDWQ       %xmm0,%xmm15
    VPHADDWQ       (%r10),%xmm12
    VPHADDWQ       %xmm15,%xmm15
    VPHADDWQ       (%rax),%xmm0
    VPHADDWQ       (%r12),%xmm15
    VPHADDWQ       (%rax),%xmm12
    VPHADDWQ       (%r10),%xmm0
# Tests for op VPHSUBBW xmm2/mem128, xmm1  (at&t syntax)
    VPHSUBBW       %xmm2,%xmm15
    VPHSUBBW       %xmm0,%xmm12
    VPHSUBBW       (%r12),%xmm0
    VPHSUBBW       (%rax),%xmm15
    VPHSUBBW       %xmm0,%xmm0
    VPHSUBBW       (%r10),%xmm15
    VPHSUBBW       %xmm2,%xmm0
    VPHSUBBW       %xmm15,%xmm12
    VPHSUBBW       %xmm15,%xmm0
    VPHSUBBW       %xmm0,%xmm15
    VPHSUBBW       (%r10),%xmm12
    VPHSUBBW       %xmm15,%xmm15
    VPHSUBBW       (%rax),%xmm0
    VPHSUBBW       (%r12),%xmm15
    VPHSUBBW       (%rax),%xmm12
    VPHSUBBW       (%r10),%xmm0
# Tests for op VPHSUBDQ xmm2/mem128, xmm1  (at&t syntax)
    VPHSUBDQ       %xmm2,%xmm15
    VPHSUBDQ       %xmm0,%xmm12
    VPHSUBDQ       (%r12),%xmm0
    VPHSUBDQ       (%rax),%xmm15
    VPHSUBDQ       %xmm0,%xmm0
    VPHSUBDQ       (%r10),%xmm15
    VPHSUBDQ       %xmm2,%xmm0
    VPHSUBDQ       %xmm15,%xmm12
    VPHSUBDQ       %xmm15,%xmm0
    VPHSUBDQ       %xmm0,%xmm15
    VPHSUBDQ       (%r10),%xmm12
    VPHSUBDQ       %xmm15,%xmm15
    VPHSUBDQ       (%rax),%xmm0
    VPHSUBDQ       (%r12),%xmm15
    VPHSUBDQ       (%rax),%xmm12
    VPHSUBDQ       (%r10),%xmm0
# Tests for op VPHSUBWD xmm2/mem128, xmm1  (at&t syntax)
    VPHSUBWD       %xmm2,%xmm15
    VPHSUBWD       %xmm0,%xmm12
    VPHSUBWD       (%r12),%xmm0
    VPHSUBWD       (%rax),%xmm15
    VPHSUBWD       %xmm0,%xmm0
    VPHSUBWD       (%r10),%xmm15
    VPHSUBWD       %xmm2,%xmm0
    VPHSUBWD       %xmm15,%xmm12
    VPHSUBWD       %xmm15,%xmm0
    VPHSUBWD       %xmm0,%xmm15
    VPHSUBWD       (%r10),%xmm12
    VPHSUBWD       %xmm15,%xmm15
    VPHSUBWD       (%rax),%xmm0
    VPHSUBWD       (%r12),%xmm15
    VPHSUBWD       (%rax),%xmm12
    VPHSUBWD       (%r10),%xmm0
# Tests for op VPMACSDD xmm4, xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPMACSDD       %xmm0,%xmm15,%xmm7,%xmm0
    VPMACSDD       %xmm2,(%r9),%xmm0,%xmm0
    VPMACSDD       %xmm15,(%r9),%xmm15,%xmm0
    VPMACSDD       %xmm15,%xmm0,%xmm0,%xmm11
    VPMACSDD       %xmm15,%xmm12,%xmm0,%xmm0
    VPMACSDD       %xmm15,%xmm12,%xmm0,%xmm15
    VPMACSDD       %xmm15,(%r12),%xmm0,%xmm15
    VPMACSDD       %xmm2,%xmm0,%xmm0,%xmm15
    VPMACSDD       %xmm2,(%r9),%xmm15,%xmm15
    VPMACSDD       %xmm2,%xmm12,%xmm15,%xmm15
    VPMACSDD       %xmm2,(%r12),%xmm15,%xmm0
    VPMACSDD       %xmm0,(%r13),%xmm15,%xmm0
    VPMACSDD       %xmm15,(%r13),%xmm7,%xmm11
    VPMACSDD       %xmm15,(%r12),%xmm7,%xmm11
    VPMACSDD       %xmm15,%xmm15,%xmm0,%xmm0
    VPMACSDD       %xmm2,(%r9),%xmm15,%xmm11
# Tests for op VPMACSDQH xmm4, xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPMACSDQH      %xmm0,%xmm15,%xmm7,%xmm0
    VPMACSDQH      %xmm2,(%r9),%xmm0,%xmm0
    VPMACSDQH      %xmm15,(%r9),%xmm15,%xmm0
    VPMACSDQH      %xmm15,%xmm0,%xmm0,%xmm11
    VPMACSDQH      %xmm15,%xmm12,%xmm0,%xmm0
    VPMACSDQH      %xmm15,%xmm12,%xmm0,%xmm15
    VPMACSDQH      %xmm15,(%r12),%xmm0,%xmm15
    VPMACSDQH      %xmm2,%xmm0,%xmm0,%xmm15
    VPMACSDQH      %xmm2,(%r9),%xmm15,%xmm15
    VPMACSDQH      %xmm2,%xmm12,%xmm15,%xmm15
    VPMACSDQH      %xmm2,(%r12),%xmm15,%xmm0
    VPMACSDQH      %xmm0,(%r13),%xmm15,%xmm0
    VPMACSDQH      %xmm15,(%r13),%xmm7,%xmm11
    VPMACSDQH      %xmm15,(%r12),%xmm7,%xmm11
    VPMACSDQH      %xmm15,%xmm15,%xmm0,%xmm0
    VPMACSDQH      %xmm2,(%r9),%xmm15,%xmm11
# Tests for op VPMACSDQL xmm4, xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPMACSDQL      %xmm0,%xmm15,%xmm7,%xmm0
    VPMACSDQL      %xmm2,(%r9),%xmm0,%xmm0
    VPMACSDQL      %xmm15,(%r9),%xmm15,%xmm0
    VPMACSDQL      %xmm15,%xmm0,%xmm0,%xmm11
    VPMACSDQL      %xmm15,%xmm12,%xmm0,%xmm0
    VPMACSDQL      %xmm15,%xmm12,%xmm0,%xmm15
    VPMACSDQL      %xmm15,(%r12),%xmm0,%xmm15
    VPMACSDQL      %xmm2,%xmm0,%xmm0,%xmm15
    VPMACSDQL      %xmm2,(%r9),%xmm15,%xmm15
    VPMACSDQL      %xmm2,%xmm12,%xmm15,%xmm15
    VPMACSDQL      %xmm2,(%r12),%xmm15,%xmm0
    VPMACSDQL      %xmm0,(%r13),%xmm15,%xmm0
    VPMACSDQL      %xmm15,(%r13),%xmm7,%xmm11
    VPMACSDQL      %xmm15,(%r12),%xmm7,%xmm11
    VPMACSDQL      %xmm15,%xmm15,%xmm0,%xmm0
    VPMACSDQL      %xmm2,(%r9),%xmm15,%xmm11
# Tests for op VPMACSSDD xmm4, xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPMACSSDD      %xmm0,%xmm15,%xmm7,%xmm0
    VPMACSSDD      %xmm2,(%r9),%xmm0,%xmm0
    VPMACSSDD      %xmm15,(%r9),%xmm15,%xmm0
    VPMACSSDD      %xmm15,%xmm0,%xmm0,%xmm11
    VPMACSSDD      %xmm15,%xmm12,%xmm0,%xmm0
    VPMACSSDD      %xmm15,%xmm12,%xmm0,%xmm15
    VPMACSSDD      %xmm15,(%r12),%xmm0,%xmm15
    VPMACSSDD      %xmm2,%xmm0,%xmm0,%xmm15
    VPMACSSDD      %xmm2,(%r9),%xmm15,%xmm15
    VPMACSSDD      %xmm2,%xmm12,%xmm15,%xmm15
    VPMACSSDD      %xmm2,(%r12),%xmm15,%xmm0
    VPMACSSDD      %xmm0,(%r13),%xmm15,%xmm0
    VPMACSSDD      %xmm15,(%r13),%xmm7,%xmm11
    VPMACSSDD      %xmm15,(%r12),%xmm7,%xmm11
    VPMACSSDD      %xmm15,%xmm15,%xmm0,%xmm0
    VPMACSSDD      %xmm2,(%r9),%xmm15,%xmm11
# Tests for op VPMACSSDQH xmm4, xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPMACSSDQH     %xmm0,%xmm15,%xmm7,%xmm0
    VPMACSSDQH     %xmm2,(%r9),%xmm0,%xmm0
    VPMACSSDQH     %xmm15,(%r9),%xmm15,%xmm0
    VPMACSSDQH     %xmm15,%xmm0,%xmm0,%xmm11
    VPMACSSDQH     %xmm15,%xmm12,%xmm0,%xmm0
    VPMACSSDQH     %xmm15,%xmm12,%xmm0,%xmm15
    VPMACSSDQH     %xmm15,(%r12),%xmm0,%xmm15
    VPMACSSDQH     %xmm2,%xmm0,%xmm0,%xmm15
    VPMACSSDQH     %xmm2,(%r9),%xmm15,%xmm15
    VPMACSSDQH     %xmm2,%xmm12,%xmm15,%xmm15
    VPMACSSDQH     %xmm2,(%r12),%xmm15,%xmm0
    VPMACSSDQH     %xmm0,(%r13),%xmm15,%xmm0
    VPMACSSDQH     %xmm15,(%r13),%xmm7,%xmm11
    VPMACSSDQH     %xmm15,(%r12),%xmm7,%xmm11
    VPMACSSDQH     %xmm15,%xmm15,%xmm0,%xmm0
    VPMACSSDQH     %xmm2,(%r9),%xmm15,%xmm11
# Tests for op VPMACSSDQL xmm4, xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPMACSSDQL     %xmm0,%xmm15,%xmm7,%xmm0
    VPMACSSDQL     %xmm2,(%r9),%xmm0,%xmm0
    VPMACSSDQL     %xmm15,(%r9),%xmm15,%xmm0
    VPMACSSDQL     %xmm15,%xmm0,%xmm0,%xmm11
    VPMACSSDQL     %xmm15,%xmm12,%xmm0,%xmm0
    VPMACSSDQL     %xmm15,%xmm12,%xmm0,%xmm15
    VPMACSSDQL     %xmm15,(%r12),%xmm0,%xmm15
    VPMACSSDQL     %xmm2,%xmm0,%xmm0,%xmm15
    VPMACSSDQL     %xmm2,(%r9),%xmm15,%xmm15
    VPMACSSDQL     %xmm2,%xmm12,%xmm15,%xmm15
    VPMACSSDQL     %xmm2,(%r12),%xmm15,%xmm0
    VPMACSSDQL     %xmm0,(%r13),%xmm15,%xmm0
    VPMACSSDQL     %xmm15,(%r13),%xmm7,%xmm11
    VPMACSSDQL     %xmm15,(%r12),%xmm7,%xmm11
    VPMACSSDQL     %xmm15,%xmm15,%xmm0,%xmm0
    VPMACSSDQL     %xmm2,(%r9),%xmm15,%xmm11
# Tests for op VPMACSSWD xmm4, xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPMACSSWD      %xmm0,%xmm15,%xmm7,%xmm0
    VPMACSSWD      %xmm2,(%r9),%xmm0,%xmm0
    VPMACSSWD      %xmm15,(%r9),%xmm15,%xmm0
    VPMACSSWD      %xmm15,%xmm0,%xmm0,%xmm11
    VPMACSSWD      %xmm15,%xmm12,%xmm0,%xmm0
    VPMACSSWD      %xmm15,%xmm12,%xmm0,%xmm15
    VPMACSSWD      %xmm15,(%r12),%xmm0,%xmm15
    VPMACSSWD      %xmm2,%xmm0,%xmm0,%xmm15
    VPMACSSWD      %xmm2,(%r9),%xmm15,%xmm15
    VPMACSSWD      %xmm2,%xmm12,%xmm15,%xmm15
    VPMACSSWD      %xmm2,(%r12),%xmm15,%xmm0
    VPMACSSWD      %xmm0,(%r13),%xmm15,%xmm0
    VPMACSSWD      %xmm15,(%r13),%xmm7,%xmm11
    VPMACSSWD      %xmm15,(%r12),%xmm7,%xmm11
    VPMACSSWD      %xmm15,%xmm15,%xmm0,%xmm0
    VPMACSSWD      %xmm2,(%r9),%xmm15,%xmm11
# Tests for op VPMACSSWW xmm4, xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPMACSSWW      %xmm0,%xmm15,%xmm7,%xmm0
    VPMACSSWW      %xmm2,(%r9),%xmm0,%xmm0
    VPMACSSWW      %xmm15,(%r9),%xmm15,%xmm0
    VPMACSSWW      %xmm15,%xmm0,%xmm0,%xmm11
    VPMACSSWW      %xmm15,%xmm12,%xmm0,%xmm0
    VPMACSSWW      %xmm15,%xmm12,%xmm0,%xmm15
    VPMACSSWW      %xmm15,(%r12),%xmm0,%xmm15
    VPMACSSWW      %xmm2,%xmm0,%xmm0,%xmm15
    VPMACSSWW      %xmm2,(%r9),%xmm15,%xmm15
    VPMACSSWW      %xmm2,%xmm12,%xmm15,%xmm15
    VPMACSSWW      %xmm2,(%r12),%xmm15,%xmm0
    VPMACSSWW      %xmm0,(%r13),%xmm15,%xmm0
    VPMACSSWW      %xmm15,(%r13),%xmm7,%xmm11
    VPMACSSWW      %xmm15,(%r12),%xmm7,%xmm11
    VPMACSSWW      %xmm15,%xmm15,%xmm0,%xmm0
    VPMACSSWW      %xmm2,(%r9),%xmm15,%xmm11
# Tests for op VPMACSWD xmm4, xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPMACSWD       %xmm0,%xmm15,%xmm7,%xmm0
    VPMACSWD       %xmm2,(%r9),%xmm0,%xmm0
    VPMACSWD       %xmm15,(%r9),%xmm15,%xmm0
    VPMACSWD       %xmm15,%xmm0,%xmm0,%xmm11
    VPMACSWD       %xmm15,%xmm12,%xmm0,%xmm0
    VPMACSWD       %xmm15,%xmm12,%xmm0,%xmm15
    VPMACSWD       %xmm15,(%r12),%xmm0,%xmm15
    VPMACSWD       %xmm2,%xmm0,%xmm0,%xmm15
    VPMACSWD       %xmm2,(%r9),%xmm15,%xmm15
    VPMACSWD       %xmm2,%xmm12,%xmm15,%xmm15
    VPMACSWD       %xmm2,(%r12),%xmm15,%xmm0
    VPMACSWD       %xmm0,(%r13),%xmm15,%xmm0
    VPMACSWD       %xmm15,(%r13),%xmm7,%xmm11
    VPMACSWD       %xmm15,(%r12),%xmm7,%xmm11
    VPMACSWD       %xmm15,%xmm15,%xmm0,%xmm0
    VPMACSWD       %xmm2,(%r9),%xmm15,%xmm11
# Tests for op VPMACSWW xmm4, xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPMACSWW       %xmm0,%xmm15,%xmm7,%xmm0
    VPMACSWW       %xmm2,(%r9),%xmm0,%xmm0
    VPMACSWW       %xmm15,(%r9),%xmm15,%xmm0
    VPMACSWW       %xmm15,%xmm0,%xmm0,%xmm11
    VPMACSWW       %xmm15,%xmm12,%xmm0,%xmm0
    VPMACSWW       %xmm15,%xmm12,%xmm0,%xmm15
    VPMACSWW       %xmm15,(%r12),%xmm0,%xmm15
    VPMACSWW       %xmm2,%xmm0,%xmm0,%xmm15
    VPMACSWW       %xmm2,(%r9),%xmm15,%xmm15
    VPMACSWW       %xmm2,%xmm12,%xmm15,%xmm15
    VPMACSWW       %xmm2,(%r12),%xmm15,%xmm0
    VPMACSWW       %xmm0,(%r13),%xmm15,%xmm0
    VPMACSWW       %xmm15,(%r13),%xmm7,%xmm11
    VPMACSWW       %xmm15,(%r12),%xmm7,%xmm11
    VPMACSWW       %xmm15,%xmm15,%xmm0,%xmm0
    VPMACSWW       %xmm2,(%r9),%xmm15,%xmm11
# Tests for op VPMADCSSWD xmm4, xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPMADCSSWD     %xmm0,%xmm15,%xmm7,%xmm0
    VPMADCSSWD     %xmm2,(%r9),%xmm0,%xmm0
    VPMADCSSWD     %xmm15,(%r9),%xmm15,%xmm0
    VPMADCSSWD     %xmm15,%xmm0,%xmm0,%xmm11
    VPMADCSSWD     %xmm15,%xmm12,%xmm0,%xmm0
    VPMADCSSWD     %xmm15,%xmm12,%xmm0,%xmm15
    VPMADCSSWD     %xmm15,(%r12),%xmm0,%xmm15
    VPMADCSSWD     %xmm2,%xmm0,%xmm0,%xmm15
    VPMADCSSWD     %xmm2,(%r9),%xmm15,%xmm15
    VPMADCSSWD     %xmm2,%xmm12,%xmm15,%xmm15
    VPMADCSSWD     %xmm2,(%r12),%xmm15,%xmm0
    VPMADCSSWD     %xmm0,(%r13),%xmm15,%xmm0
    VPMADCSSWD     %xmm15,(%r13),%xmm7,%xmm11
    VPMADCSSWD     %xmm15,(%r12),%xmm7,%xmm11
    VPMADCSSWD     %xmm15,%xmm15,%xmm0,%xmm0
    VPMADCSSWD     %xmm2,(%r9),%xmm15,%xmm11
# Tests for op VPMADCSWD xmm4, xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPMADCSWD      %xmm0,%xmm15,%xmm7,%xmm0
    VPMADCSWD      %xmm2,(%r9),%xmm0,%xmm0
    VPMADCSWD      %xmm15,(%r9),%xmm15,%xmm0
    VPMADCSWD      %xmm15,%xmm0,%xmm0,%xmm11
    VPMADCSWD      %xmm15,%xmm12,%xmm0,%xmm0
    VPMADCSWD      %xmm15,%xmm12,%xmm0,%xmm15
    VPMADCSWD      %xmm15,(%r12),%xmm0,%xmm15
    VPMADCSWD      %xmm2,%xmm0,%xmm0,%xmm15
    VPMADCSWD      %xmm2,(%r9),%xmm15,%xmm15
    VPMADCSWD      %xmm2,%xmm12,%xmm15,%xmm15
    VPMADCSWD      %xmm2,(%r12),%xmm15,%xmm0
    VPMADCSWD      %xmm0,(%r13),%xmm15,%xmm0
    VPMADCSWD      %xmm15,(%r13),%xmm7,%xmm11
    VPMADCSWD      %xmm15,(%r12),%xmm7,%xmm11
    VPMADCSWD      %xmm15,%xmm15,%xmm0,%xmm0
    VPMADCSWD      %xmm2,(%r9),%xmm15,%xmm11
# Tests for op VPPERM xmm4/mem128, xmm3, xmm2, xmm1  (at&t syntax)
    VPPERM         %xmm0,%xmm12,%xmm7,%xmm0
    VPPERM         (%rax),%xmm15,%xmm0,%xmm0
    VPPERM         (%r10),%xmm15,%xmm15,%xmm0
    VPPERM         %xmm2,%xmm0,%xmm0,%xmm11
    VPPERM         %xmm2,%xmm0,%xmm0,%xmm0
    VPPERM         %xmm2,%xmm0,%xmm0,%xmm15
    VPPERM         (%r10),%xmm12,%xmm0,%xmm15
    VPPERM         (%rax),%xmm0,%xmm0,%xmm15
    VPPERM         (%r12),%xmm15,%xmm15,%xmm15
    VPPERM         (%r12),%xmm0,%xmm15,%xmm15
    VPPERM         (%rax),%xmm12,%xmm15,%xmm0
    VPPERM         %xmm15,%xmm15,%xmm15,%xmm0
    VPPERM         (%r10),%xmm15,%xmm7,%xmm11
    VPPERM         %xmm2,%xmm12,%xmm7,%xmm11
    VPPERM         %xmm2,%xmm12,%xmm0,%xmm0
    VPPERM         (%r12),%xmm15,%xmm15,%xmm11
# Tests for op VPPERM xmm4, xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPPERM         %xmm0,%xmm15,%xmm7,%xmm0
    VPPERM         %xmm2,(%r9),%xmm0,%xmm0
    VPPERM         %xmm15,(%r9),%xmm15,%xmm0
    VPPERM         %xmm15,%xmm0,%xmm0,%xmm11
    VPPERM         %xmm15,%xmm12,%xmm0,%xmm0
    VPPERM         %xmm15,%xmm12,%xmm0,%xmm15
    VPPERM         %xmm15,(%r12),%xmm0,%xmm15
    VPPERM         %xmm2,%xmm0,%xmm0,%xmm15
    VPPERM         %xmm2,(%r9),%xmm15,%xmm15
    VPPERM         %xmm2,%xmm12,%xmm15,%xmm15
    VPPERM         %xmm2,(%r12),%xmm15,%xmm0
    VPPERM         %xmm0,(%r13),%xmm15,%xmm0
    VPPERM         %xmm15,(%r13),%xmm7,%xmm11
    VPPERM         %xmm15,(%r12),%xmm7,%xmm11
    VPPERM         %xmm15,%xmm15,%xmm0,%xmm0
    VPPERM         %xmm2,(%r9),%xmm15,%xmm11
# Tests for op VPROTB xmm3, xmm2/mem128, xmm1  (at&t syntax)
    VPROTB         %xmm2,%xmm0,%xmm15
    VPROTB         %xmm2,%xmm12,%xmm7
    VPROTB         %xmm2,%xmm0,%xmm0
    VPROTB         %xmm15,(%r9),%xmm15
    VPROTB         %xmm0,%xmm15,%xmm0
    VPROTB         %xmm0,%xmm15,%xmm15
    VPROTB         %xmm0,%xmm12,%xmm0
    VPROTB         %xmm15,%xmm12,%xmm0
    VPROTB         %xmm2,(%r12),%xmm15
    VPROTB         %xmm0,(%r9),%xmm7
    VPROTB         %xmm0,%xmm12,%xmm7
    VPROTB         %xmm2,(%r9),%xmm15
    VPROTB         %xmm2,(%r13),%xmm0
    VPROTB         %xmm15,(%r9),%xmm7
    VPROTB         %xmm15,(%r12),%xmm0
    VPROTB         %xmm0,(%r13),%xmm15
# Tests for op VPROTB xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPROTB         (%r12),%xmm0,%xmm15
    VPROTB         (%r12),%xmm0,%xmm7
    VPROTB         (%rax),%xmm0,%xmm0
    VPROTB         (%r10),%xmm15,%xmm15
    VPROTB         %xmm15,%xmm12,%xmm0
    VPROTB         %xmm15,%xmm12,%xmm15
    VPROTB         %xmm15,%xmm0,%xmm0
    VPROTB         %xmm2,%xmm0,%xmm0
    VPROTB         (%rax),%xmm12,%xmm15
    VPROTB         %xmm15,%xmm15,%xmm7
    VPROTB         %xmm0,%xmm0,%xmm7
    VPROTB         (%r12),%xmm15,%xmm15
    VPROTB         (%r12),%xmm15,%xmm0
    VPROTB         (%r10),%xmm15,%xmm7
    VPROTB         (%r10),%xmm12,%xmm0
    VPROTB         %xmm15,%xmm15,%xmm15
# Tests for op VPROTB imm8, xmm2, xmm1  (at&t syntax)
    VPROTB         $0x3,%xmm11,%xmm15
    VPROTB         $-1,%xmm0,%xmm0
    VPROTB         $-1,%xmm11,%xmm4
    VPROTB         $0x0,%xmm11,%xmm4
    VPROTB         $0x0,%xmm15,%xmm4
    VPROTB         $0x0,%xmm0,%xmm15
    VPROTB         $-1,%xmm11,%xmm0
    VPROTB         $0x3,%xmm0,%xmm0
    VPROTB         $0x3,%xmm11,%xmm0
    VPROTB         $0x0,%xmm0,%xmm4
    VPROTB         $-1,%xmm15,%xmm0
    VPROTB         $-1,%xmm0,%xmm15
    VPROTB         $-1,%xmm15,%xmm15
    VPROTB         $0x3,%xmm15,%xmm4
    VPROTB         $-1,%xmm11,%xmm15
    VPROTB         $0x3,%xmm0,%xmm15
# Tests for op VPROTD xmm3, xmm2/mem128, xmm1  (at&t syntax)
    VPROTD         %xmm2,%xmm0,%xmm15
    VPROTD         %xmm2,%xmm12,%xmm7
    VPROTD         %xmm2,%xmm0,%xmm0
    VPROTD         %xmm15,(%r9),%xmm15
    VPROTD         %xmm0,%xmm15,%xmm0
    VPROTD         %xmm0,%xmm15,%xmm15
    VPROTD         %xmm0,%xmm12,%xmm0
    VPROTD         %xmm15,%xmm12,%xmm0
    VPROTD         %xmm2,(%r12),%xmm15
    VPROTD         %xmm0,(%r9),%xmm7
    VPROTD         %xmm0,%xmm12,%xmm7
    VPROTD         %xmm2,(%r9),%xmm15
    VPROTD         %xmm2,(%r13),%xmm0
    VPROTD         %xmm15,(%r9),%xmm7
    VPROTD         %xmm15,(%r12),%xmm0
    VPROTD         %xmm0,(%r13),%xmm15
# Tests for op VPROTD xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPROTD         (%r12),%xmm0,%xmm15
    VPROTD         (%r12),%xmm0,%xmm7
    VPROTD         (%rax),%xmm0,%xmm0
    VPROTD         (%r10),%xmm15,%xmm15
    VPROTD         %xmm15,%xmm12,%xmm0
    VPROTD         %xmm15,%xmm12,%xmm15
    VPROTD         %xmm15,%xmm0,%xmm0
    VPROTD         %xmm2,%xmm0,%xmm0
    VPROTD         (%rax),%xmm12,%xmm15
    VPROTD         %xmm15,%xmm15,%xmm7
    VPROTD         %xmm0,%xmm0,%xmm7
    VPROTD         (%r12),%xmm15,%xmm15
    VPROTD         (%r12),%xmm15,%xmm0
    VPROTD         (%r10),%xmm15,%xmm7
    VPROTD         (%r10),%xmm12,%xmm0
    VPROTD         %xmm15,%xmm15,%xmm15
# Tests for op VPROTD imm8, xmm2/mem128, xmm1  (at&t syntax)
    VPROTD         $0x0,%xmm15,%xmm15
    VPROTD         $0x0,(%rsi),%xmm15
    VPROTD         $0x0,%xmm0,%xmm11
    VPROTD         $-1,%xmm15,%xmm0
    VPROTD         $0x3,%xmm0,%xmm0
    VPROTD         $0x3,%xmm15,%xmm0
    VPROTD         $0x0,%xmm11,%xmm11
    VPROTD         $0x0,%xmm0,%xmm15
    VPROTD         $0x3,(%rcx),%xmm0
    VPROTD         $-1,(%rsi),%xmm0
    VPROTD         $0x0,(%rdi),%xmm15
    VPROTD         $-1,%xmm15,%xmm15
    VPROTD         $-1,%xmm11,%xmm11
    VPROTD         $-1,(%rsi),%xmm11
    VPROTD         $0x3,(%rdi),%xmm15
    VPROTD         $0x3,%xmm15,%xmm11
# Tests for op VPROTQ xmm3, xmm2/mem128, xmm1  (at&t syntax)
    VPROTQ         %xmm2,%xmm0,%xmm15
    VPROTQ         %xmm2,%xmm12,%xmm7
    VPROTQ         %xmm2,%xmm0,%xmm0
    VPROTQ         %xmm15,(%r9),%xmm15
    VPROTQ         %xmm0,%xmm15,%xmm0
    VPROTQ         %xmm0,%xmm15,%xmm15
    VPROTQ         %xmm0,%xmm12,%xmm0
    VPROTQ         %xmm15,%xmm12,%xmm0
    VPROTQ         %xmm2,(%r12),%xmm15
    VPROTQ         %xmm0,(%r9),%xmm7
    VPROTQ         %xmm0,%xmm12,%xmm7
    VPROTQ         %xmm2,(%r9),%xmm15
    VPROTQ         %xmm2,(%r13),%xmm0
    VPROTQ         %xmm15,(%r9),%xmm7
    VPROTQ         %xmm15,(%r12),%xmm0
    VPROTQ         %xmm0,(%r13),%xmm15
# Tests for op VPROTQ xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPROTQ         (%r12),%xmm0,%xmm15
    VPROTQ         (%r12),%xmm0,%xmm7
    VPROTQ         (%rax),%xmm0,%xmm0
    VPROTQ         (%r10),%xmm15,%xmm15
    VPROTQ         %xmm15,%xmm12,%xmm0
    VPROTQ         %xmm15,%xmm12,%xmm15
    VPROTQ         %xmm15,%xmm0,%xmm0
    VPROTQ         %xmm2,%xmm0,%xmm0
    VPROTQ         (%rax),%xmm12,%xmm15
    VPROTQ         %xmm15,%xmm15,%xmm7
    VPROTQ         %xmm0,%xmm0,%xmm7
    VPROTQ         (%r12),%xmm15,%xmm15
    VPROTQ         (%r12),%xmm15,%xmm0
    VPROTQ         (%r10),%xmm15,%xmm7
    VPROTQ         (%r10),%xmm12,%xmm0
    VPROTQ         %xmm15,%xmm15,%xmm15
# Tests for op VPROTQ imm8, xmm2/mem128, xmm1  (at&t syntax)
    VPROTQ         $0x0,%xmm15,%xmm15
    VPROTQ         $0x0,(%rsi),%xmm15
    VPROTQ         $0x0,%xmm0,%xmm11
    VPROTQ         $-1,%xmm15,%xmm0
    VPROTQ         $0x3,%xmm0,%xmm0
    VPROTQ         $0x3,%xmm15,%xmm0
    VPROTQ         $0x0,%xmm11,%xmm11
    VPROTQ         $0x0,%xmm0,%xmm15
    VPROTQ         $0x3,(%rcx),%xmm0
    VPROTQ         $-1,(%rsi),%xmm0
    VPROTQ         $0x0,(%rdi),%xmm15
    VPROTQ         $-1,%xmm15,%xmm15
    VPROTQ         $-1,%xmm11,%xmm11
    VPROTQ         $-1,(%rsi),%xmm11
    VPROTQ         $0x3,(%rdi),%xmm15
    VPROTQ         $0x3,%xmm15,%xmm11
# Tests for op VPROTW xmm3, xmm2/mem128, xmm1  (at&t syntax)
    VPROTW         %xmm2,%xmm0,%xmm15
    VPROTW         %xmm2,%xmm12,%xmm7
    VPROTW         %xmm2,%xmm0,%xmm0
    VPROTW         %xmm15,(%r9),%xmm15
    VPROTW         %xmm0,%xmm15,%xmm0
    VPROTW         %xmm0,%xmm15,%xmm15
    VPROTW         %xmm0,%xmm12,%xmm0
    VPROTW         %xmm15,%xmm12,%xmm0
    VPROTW         %xmm2,(%r12),%xmm15
    VPROTW         %xmm0,(%r9),%xmm7
    VPROTW         %xmm0,%xmm12,%xmm7
    VPROTW         %xmm2,(%r9),%xmm15
    VPROTW         %xmm2,(%r13),%xmm0
    VPROTW         %xmm15,(%r9),%xmm7
    VPROTW         %xmm15,(%r12),%xmm0
    VPROTW         %xmm0,(%r13),%xmm15
# Tests for op VPROTW xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPROTW         (%r12),%xmm0,%xmm15
    VPROTW         (%r12),%xmm0,%xmm7
    VPROTW         (%rax),%xmm0,%xmm0
    VPROTW         (%r10),%xmm15,%xmm15
    VPROTW         %xmm15,%xmm12,%xmm0
    VPROTW         %xmm15,%xmm12,%xmm15
    VPROTW         %xmm15,%xmm0,%xmm0
    VPROTW         %xmm2,%xmm0,%xmm0
    VPROTW         (%rax),%xmm12,%xmm15
    VPROTW         %xmm15,%xmm15,%xmm7
    VPROTW         %xmm0,%xmm0,%xmm7
    VPROTW         (%r12),%xmm15,%xmm15
    VPROTW         (%r12),%xmm15,%xmm0
    VPROTW         (%r10),%xmm15,%xmm7
    VPROTW         (%r10),%xmm12,%xmm0
    VPROTW         %xmm15,%xmm15,%xmm15
# Tests for op VPROTW imm8, xmm2/mem128, xmm1  (at&t syntax)
    VPROTW         $0x0,%xmm15,%xmm15
    VPROTW         $0x0,(%rsi),%xmm15
    VPROTW         $0x0,%xmm0,%xmm11
    VPROTW         $-1,%xmm15,%xmm0
    VPROTW         $0x3,%xmm0,%xmm0
    VPROTW         $0x3,%xmm15,%xmm0
    VPROTW         $0x0,%xmm11,%xmm11
    VPROTW         $0x0,%xmm0,%xmm15
    VPROTW         $0x3,(%rcx),%xmm0
    VPROTW         $-1,(%rsi),%xmm0
    VPROTW         $0x0,(%rdi),%xmm15
    VPROTW         $-1,%xmm15,%xmm15
    VPROTW         $-1,%xmm11,%xmm11
    VPROTW         $-1,(%rsi),%xmm11
    VPROTW         $0x3,(%rdi),%xmm15
    VPROTW         $0x3,%xmm15,%xmm11
# Tests for op VPSHAB xmm3, xmm2/mem128, xmm1  (at&t syntax)
    VPSHAB         %xmm2,%xmm0,%xmm15
    VPSHAB         %xmm2,%xmm12,%xmm7
    VPSHAB         %xmm2,%xmm0,%xmm0
    VPSHAB         %xmm15,(%r9),%xmm15
    VPSHAB         %xmm0,%xmm15,%xmm0
    VPSHAB         %xmm0,%xmm15,%xmm15
    VPSHAB         %xmm0,%xmm12,%xmm0
    VPSHAB         %xmm15,%xmm12,%xmm0
    VPSHAB         %xmm2,(%r12),%xmm15
    VPSHAB         %xmm0,(%r9),%xmm7
    VPSHAB         %xmm0,%xmm12,%xmm7
    VPSHAB         %xmm2,(%r9),%xmm15
    VPSHAB         %xmm2,(%r13),%xmm0
    VPSHAB         %xmm15,(%r9),%xmm7
    VPSHAB         %xmm15,(%r12),%xmm0
    VPSHAB         %xmm0,(%r13),%xmm15
# Tests for op VPSHAB xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPSHAB         (%r12),%xmm0,%xmm15
    VPSHAB         (%r12),%xmm0,%xmm7
    VPSHAB         (%rax),%xmm0,%xmm0
    VPSHAB         (%r10),%xmm15,%xmm15
    VPSHAB         %xmm15,%xmm12,%xmm0
    VPSHAB         %xmm15,%xmm12,%xmm15
    VPSHAB         %xmm15,%xmm0,%xmm0
    VPSHAB         %xmm2,%xmm0,%xmm0
    VPSHAB         (%rax),%xmm12,%xmm15
    VPSHAB         %xmm15,%xmm15,%xmm7
    VPSHAB         %xmm0,%xmm0,%xmm7
    VPSHAB         (%r12),%xmm15,%xmm15
    VPSHAB         (%r12),%xmm15,%xmm0
    VPSHAB         (%r10),%xmm15,%xmm7
    VPSHAB         (%r10),%xmm12,%xmm0
    VPSHAB         %xmm15,%xmm15,%xmm15
# Tests for op VPSHAD xmm3, xmm2/mem128, xmm1  (at&t syntax)
    VPSHAD         %xmm2,%xmm0,%xmm15
    VPSHAD         %xmm2,%xmm12,%xmm7
    VPSHAD         %xmm2,%xmm0,%xmm0
    VPSHAD         %xmm15,(%r9),%xmm15
    VPSHAD         %xmm0,%xmm15,%xmm0
    VPSHAD         %xmm0,%xmm15,%xmm15
    VPSHAD         %xmm0,%xmm12,%xmm0
    VPSHAD         %xmm15,%xmm12,%xmm0
    VPSHAD         %xmm2,(%r12),%xmm15
    VPSHAD         %xmm0,(%r9),%xmm7
    VPSHAD         %xmm0,%xmm12,%xmm7
    VPSHAD         %xmm2,(%r9),%xmm15
    VPSHAD         %xmm2,(%r13),%xmm0
    VPSHAD         %xmm15,(%r9),%xmm7
    VPSHAD         %xmm15,(%r12),%xmm0
    VPSHAD         %xmm0,(%r13),%xmm15
# Tests for op VPSHAD xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPSHAD         (%r12),%xmm0,%xmm15
    VPSHAD         (%r12),%xmm0,%xmm7
    VPSHAD         (%rax),%xmm0,%xmm0
    VPSHAD         (%r10),%xmm15,%xmm15
    VPSHAD         %xmm15,%xmm12,%xmm0
    VPSHAD         %xmm15,%xmm12,%xmm15
    VPSHAD         %xmm15,%xmm0,%xmm0
    VPSHAD         %xmm2,%xmm0,%xmm0
    VPSHAD         (%rax),%xmm12,%xmm15
    VPSHAD         %xmm15,%xmm15,%xmm7
    VPSHAD         %xmm0,%xmm0,%xmm7
    VPSHAD         (%r12),%xmm15,%xmm15
    VPSHAD         (%r12),%xmm15,%xmm0
    VPSHAD         (%r10),%xmm15,%xmm7
    VPSHAD         (%r10),%xmm12,%xmm0
    VPSHAD         %xmm15,%xmm15,%xmm15
# Tests for op VPSHAQ xmm3, xmm2/mem128, xmm1  (at&t syntax)
    VPSHAQ         %xmm2,%xmm0,%xmm15
    VPSHAQ         %xmm2,%xmm12,%xmm7
    VPSHAQ         %xmm2,%xmm0,%xmm0
    VPSHAQ         %xmm15,(%r9),%xmm15
    VPSHAQ         %xmm0,%xmm15,%xmm0
    VPSHAQ         %xmm0,%xmm15,%xmm15
    VPSHAQ         %xmm0,%xmm12,%xmm0
    VPSHAQ         %xmm15,%xmm12,%xmm0
    VPSHAQ         %xmm2,(%r12),%xmm15
    VPSHAQ         %xmm0,(%r9),%xmm7
    VPSHAQ         %xmm0,%xmm12,%xmm7
    VPSHAQ         %xmm2,(%r9),%xmm15
    VPSHAQ         %xmm2,(%r13),%xmm0
    VPSHAQ         %xmm15,(%r9),%xmm7
    VPSHAQ         %xmm15,(%r12),%xmm0
    VPSHAQ         %xmm0,(%r13),%xmm15
# Tests for op VPSHAQ xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPSHAQ         (%r12),%xmm0,%xmm15
    VPSHAQ         (%r12),%xmm0,%xmm7
    VPSHAQ         (%rax),%xmm0,%xmm0
    VPSHAQ         (%r10),%xmm15,%xmm15
    VPSHAQ         %xmm15,%xmm12,%xmm0
    VPSHAQ         %xmm15,%xmm12,%xmm15
    VPSHAQ         %xmm15,%xmm0,%xmm0
    VPSHAQ         %xmm2,%xmm0,%xmm0
    VPSHAQ         (%rax),%xmm12,%xmm15
    VPSHAQ         %xmm15,%xmm15,%xmm7
    VPSHAQ         %xmm0,%xmm0,%xmm7
    VPSHAQ         (%r12),%xmm15,%xmm15
    VPSHAQ         (%r12),%xmm15,%xmm0
    VPSHAQ         (%r10),%xmm15,%xmm7
    VPSHAQ         (%r10),%xmm12,%xmm0
    VPSHAQ         %xmm15,%xmm15,%xmm15
# Tests for op VPSHAW xmm3, xmm2/mem128, xmm1  (at&t syntax)
    VPSHAW         %xmm2,%xmm0,%xmm15
    VPSHAW         %xmm2,%xmm12,%xmm7
    VPSHAW         %xmm2,%xmm0,%xmm0
    VPSHAW         %xmm15,(%r9),%xmm15
    VPSHAW         %xmm0,%xmm15,%xmm0
    VPSHAW         %xmm0,%xmm15,%xmm15
    VPSHAW         %xmm0,%xmm12,%xmm0
    VPSHAW         %xmm15,%xmm12,%xmm0
    VPSHAW         %xmm2,(%r12),%xmm15
    VPSHAW         %xmm0,(%r9),%xmm7
    VPSHAW         %xmm0,%xmm12,%xmm7
    VPSHAW         %xmm2,(%r9),%xmm15
    VPSHAW         %xmm2,(%r13),%xmm0
    VPSHAW         %xmm15,(%r9),%xmm7
    VPSHAW         %xmm15,(%r12),%xmm0
    VPSHAW         %xmm0,(%r13),%xmm15
# Tests for op VPSHAW xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPSHAW         (%r12),%xmm0,%xmm15
    VPSHAW         (%r12),%xmm0,%xmm7
    VPSHAW         (%rax),%xmm0,%xmm0
    VPSHAW         (%r10),%xmm15,%xmm15
    VPSHAW         %xmm15,%xmm12,%xmm0
    VPSHAW         %xmm15,%xmm12,%xmm15
    VPSHAW         %xmm15,%xmm0,%xmm0
    VPSHAW         %xmm2,%xmm0,%xmm0
    VPSHAW         (%rax),%xmm12,%xmm15
    VPSHAW         %xmm15,%xmm15,%xmm7
    VPSHAW         %xmm0,%xmm0,%xmm7
    VPSHAW         (%r12),%xmm15,%xmm15
    VPSHAW         (%r12),%xmm15,%xmm0
    VPSHAW         (%r10),%xmm15,%xmm7
    VPSHAW         (%r10),%xmm12,%xmm0
    VPSHAW         %xmm15,%xmm15,%xmm15
# Tests for op VPSHLB xmm3, xmm2/mem128, xmm1  (at&t syntax)
    VPSHLB         %xmm2,%xmm0,%xmm15
    VPSHLB         %xmm2,%xmm12,%xmm7
    VPSHLB         %xmm2,%xmm0,%xmm0
    VPSHLB         %xmm15,(%r9),%xmm15
    VPSHLB         %xmm0,%xmm15,%xmm0
    VPSHLB         %xmm0,%xmm15,%xmm15
    VPSHLB         %xmm0,%xmm12,%xmm0
    VPSHLB         %xmm15,%xmm12,%xmm0
    VPSHLB         %xmm2,(%r12),%xmm15
    VPSHLB         %xmm0,(%r9),%xmm7
    VPSHLB         %xmm0,%xmm12,%xmm7
    VPSHLB         %xmm2,(%r9),%xmm15
    VPSHLB         %xmm2,(%r13),%xmm0
    VPSHLB         %xmm15,(%r9),%xmm7
    VPSHLB         %xmm15,(%r12),%xmm0
    VPSHLB         %xmm0,(%r13),%xmm15
# Tests for op VPSHLB xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPSHLB         (%r12),%xmm0,%xmm15
    VPSHLB         (%r12),%xmm0,%xmm7
    VPSHLB         (%rax),%xmm0,%xmm0
    VPSHLB         (%r10),%xmm15,%xmm15
    VPSHLB         %xmm15,%xmm12,%xmm0
    VPSHLB         %xmm15,%xmm12,%xmm15
    VPSHLB         %xmm15,%xmm0,%xmm0
    VPSHLB         %xmm2,%xmm0,%xmm0
    VPSHLB         (%rax),%xmm12,%xmm15
    VPSHLB         %xmm15,%xmm15,%xmm7
    VPSHLB         %xmm0,%xmm0,%xmm7
    VPSHLB         (%r12),%xmm15,%xmm15
    VPSHLB         (%r12),%xmm15,%xmm0
    VPSHLB         (%r10),%xmm15,%xmm7
    VPSHLB         (%r10),%xmm12,%xmm0
    VPSHLB         %xmm15,%xmm15,%xmm15
# Tests for op VPSHLD xmm2, xmm3/mem128, xmm1  (at&t syntax)
    VPSHLD         %xmm2,%xmm0,%xmm15
    VPSHLD         %xmm2,%xmm12,%xmm7
    VPSHLD         %xmm2,%xmm0,%xmm0
    VPSHLD         %xmm15,(%r9),%xmm15
    VPSHLD         %xmm0,%xmm15,%xmm0
    VPSHLD         %xmm0,%xmm15,%xmm15
    VPSHLD         %xmm0,%xmm12,%xmm0
    VPSHLD         %xmm15,%xmm12,%xmm0
    VPSHLD         %xmm2,(%r12),%xmm15
    VPSHLD         %xmm0,(%r9),%xmm7
    VPSHLD         %xmm0,%xmm12,%xmm7
    VPSHLD         %xmm2,(%r9),%xmm15
    VPSHLD         %xmm2,(%r13),%xmm0
    VPSHLD         %xmm15,(%r9),%xmm7
    VPSHLD         %xmm15,(%r12),%xmm0
    VPSHLD         %xmm0,(%r13),%xmm15
# Tests for op VPSHLD xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPSHLD         (%r12),%xmm0,%xmm15
    VPSHLD         (%r12),%xmm0,%xmm7
    VPSHLD         (%rax),%xmm0,%xmm0
    VPSHLD         (%r10),%xmm15,%xmm15
    VPSHLD         %xmm15,%xmm12,%xmm0
    VPSHLD         %xmm15,%xmm12,%xmm15
    VPSHLD         %xmm15,%xmm0,%xmm0
    VPSHLD         %xmm2,%xmm0,%xmm0
    VPSHLD         (%rax),%xmm12,%xmm15
    VPSHLD         %xmm15,%xmm15,%xmm7
    VPSHLD         %xmm0,%xmm0,%xmm7
    VPSHLD         (%r12),%xmm15,%xmm15
    VPSHLD         (%r12),%xmm15,%xmm0
    VPSHLD         (%r10),%xmm15,%xmm7
    VPSHLD         (%r10),%xmm12,%xmm0
    VPSHLD         %xmm15,%xmm15,%xmm15
# Tests for op VPSHLQ xmm2, xmm3/mem128, xmm1  (at&t syntax)
    VPSHLQ         %xmm2,%xmm0,%xmm15
    VPSHLQ         %xmm2,%xmm12,%xmm7
    VPSHLQ         %xmm2,%xmm0,%xmm0
    VPSHLQ         %xmm15,(%r9),%xmm15
    VPSHLQ         %xmm0,%xmm15,%xmm0
    VPSHLQ         %xmm0,%xmm15,%xmm15
    VPSHLQ         %xmm0,%xmm12,%xmm0
    VPSHLQ         %xmm15,%xmm12,%xmm0
    VPSHLQ         %xmm2,(%r12),%xmm15
    VPSHLQ         %xmm0,(%r9),%xmm7
    VPSHLQ         %xmm0,%xmm12,%xmm7
    VPSHLQ         %xmm2,(%r9),%xmm15
    VPSHLQ         %xmm2,(%r13),%xmm0
    VPSHLQ         %xmm15,(%r9),%xmm7
    VPSHLQ         %xmm15,(%r12),%xmm0
    VPSHLQ         %xmm0,(%r13),%xmm15
# Tests for op VPSHLQ xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPSHLQ         (%r12),%xmm0,%xmm15
    VPSHLQ         (%r12),%xmm0,%xmm7
    VPSHLQ         (%rax),%xmm0,%xmm0
    VPSHLQ         (%r10),%xmm15,%xmm15
    VPSHLQ         %xmm15,%xmm12,%xmm0
    VPSHLQ         %xmm15,%xmm12,%xmm15
    VPSHLQ         %xmm15,%xmm0,%xmm0
    VPSHLQ         %xmm2,%xmm0,%xmm0
    VPSHLQ         (%rax),%xmm12,%xmm15
    VPSHLQ         %xmm15,%xmm15,%xmm7
    VPSHLQ         %xmm0,%xmm0,%xmm7
    VPSHLQ         (%r12),%xmm15,%xmm15
    VPSHLQ         (%r12),%xmm15,%xmm0
    VPSHLQ         (%r10),%xmm15,%xmm7
    VPSHLQ         (%r10),%xmm12,%xmm0
    VPSHLQ         %xmm15,%xmm15,%xmm15
# Tests for op VPSHLW xmm2, xmm3/mem128, xmm1  (at&t syntax)
    VPSHLW         %xmm2,%xmm0,%xmm15
    VPSHLW         %xmm2,%xmm12,%xmm7
    VPSHLW         %xmm2,%xmm0,%xmm0
    VPSHLW         %xmm15,(%r9),%xmm15
    VPSHLW         %xmm0,%xmm15,%xmm0
    VPSHLW         %xmm0,%xmm15,%xmm15
    VPSHLW         %xmm0,%xmm12,%xmm0
    VPSHLW         %xmm15,%xmm12,%xmm0
    VPSHLW         %xmm2,(%r12),%xmm15
    VPSHLW         %xmm0,(%r9),%xmm7
    VPSHLW         %xmm0,%xmm12,%xmm7
    VPSHLW         %xmm2,(%r9),%xmm15
    VPSHLW         %xmm2,(%r13),%xmm0
    VPSHLW         %xmm15,(%r9),%xmm7
    VPSHLW         %xmm15,(%r12),%xmm0
    VPSHLW         %xmm0,(%r13),%xmm15
# Tests for op VPSHLW xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPSHLW         (%r12),%xmm0,%xmm15
    VPSHLW         (%r12),%xmm0,%xmm7
    VPSHLW         (%rax),%xmm0,%xmm0
    VPSHLW         (%r10),%xmm15,%xmm15
    VPSHLW         %xmm15,%xmm12,%xmm0
    VPSHLW         %xmm15,%xmm12,%xmm15
    VPSHLW         %xmm15,%xmm0,%xmm0
    VPSHLW         %xmm2,%xmm0,%xmm0
    VPSHLW         (%rax),%xmm12,%xmm15
    VPSHLW         %xmm15,%xmm15,%xmm7
    VPSHLW         %xmm0,%xmm0,%xmm7
    VPSHLW         (%r12),%xmm15,%xmm15
    VPSHLW         (%r12),%xmm15,%xmm0
    VPSHLW         (%r10),%xmm15,%xmm7
    VPSHLW         (%r10),%xmm12,%xmm0
    VPSHLW         %xmm15,%xmm15,%xmm15
# All variants of VPCOM* aliases
    VPCOMLTB       %xmm8,%xmm11,%xmm0
    VPCOMLTB       (%r12),%xmm11,%xmm15
    VPCOMLTB       (%rdi,%rcx),%xmm0,%xmm0
    VPCOMLTB       %xmm15,%xmm0,%xmm15
    VPCOMLTB       (%rdi,%rcx),%xmm15,%xmm7
    VPCOMLTB       (%rdi,%rcx),%xmm11,%xmm0
    VPCOMLTB       0x6(%r9,%r11,2),%xmm15,%xmm15
    VPCOMLTB       (%rbx,%rax,4),%xmm15,%xmm7
    VPCOMLTD       (%rdi,%rcx),%xmm11,%xmm15
    VPCOMLTD       %xmm0,%xmm15,%xmm0
    VPCOMLTD       (%r12),%xmm15,%xmm7
    VPCOMLTD       %xmm15,%xmm0,%xmm15
    VPCOMLTD       %xmm0,%xmm11,%xmm15
    VPCOMLTD       (%r12),%xmm11,%xmm0
    VPCOMLTD       %xmm8,%xmm0,%xmm15
    VPCOMLTD       %xmm15,%xmm0,%xmm0
    VPCOMLTQ       %xmm0,%xmm11,%xmm7
    VPCOMLTQ       %xmm15,%xmm11,%xmm7
    VPCOMLTQ       %xmm15,%xmm11,%xmm0
    VPCOMLTQ       (%rdi,%rcx),%xmm0,%xmm15
    VPCOMLTQ       0x6(%r9,%r11,2),%xmm11,%xmm0
    VPCOMLTQ       (%r12),%xmm15,%xmm15
    VPCOMLTQ       %xmm15,%xmm0,%xmm0
    VPCOMLTQ       (%rdi,%rcx),%xmm0,%xmm7
    VPCOMLTUB      %xmm0,%xmm0,%xmm15
    VPCOMLTUB      0x6(%r9,%r11,2),%xmm15,%xmm15
    VPCOMLTUB      (%rdi,%rcx),%xmm0,%xmm7
    VPCOMLTUB      %xmm8,%xmm11,%xmm15
    VPCOMLTUB      (%rbx,%rax,4),%xmm11,%xmm7
    VPCOMLTUB      (%rdi,%rcx),%xmm11,%xmm15
    VPCOMLTUB      %xmm8,%xmm11,%xmm7
    VPCOMLTUB      (%r12),%xmm15,%xmm7
    VPCOMLTUD      %xmm0,%xmm0,%xmm7
    VPCOMLTUD      %xmm15,%xmm15,%xmm0
    VPCOMLTUD      %xmm15,%xmm0,%xmm7
    VPCOMLTUD      (%rdi,%rcx),%xmm11,%xmm15
    VPCOMLTUD      (%rdi,%rcx),%xmm11,%xmm7
    VPCOMLTUD      %xmm15,%xmm0,%xmm15
    VPCOMLTUD      0x6(%r9,%r11,2),%xmm0,%xmm7
    VPCOMLTUD      0x6(%r9,%r11,2),%xmm0,%xmm0
    VPCOMLTUQ      %xmm15,%xmm0,%xmm0
    VPCOMLTUQ      (%rbx,%rax,4),%xmm0,%xmm7
    VPCOMLTUQ      (%r12),%xmm11,%xmm15
    VPCOMLTUQ      (%rdi,%rcx),%xmm0,%xmm0
    VPCOMLTUQ      %xmm0,%xmm11,%xmm0
    VPCOMLTUQ      (%rdi,%rcx),%xmm11,%xmm7
    VPCOMLTUQ      (%rdi,%rcx),%xmm0,%xmm15
    VPCOMLTUQ      (%r12),%xmm0,%xmm7
    VPCOMLTUW      (%rbx,%rax,4),%xmm11,%xmm7
    VPCOMLTUW      (%rbx,%rax,4),%xmm15,%xmm15
    VPCOMLTUW      %xmm8,%xmm11,%xmm7
    VPCOMLTUW      (%r12),%xmm15,%xmm7
    VPCOMLTUW      (%rdi,%rcx),%xmm11,%xmm7
    VPCOMLTUW      (%rbx,%rax,4),%xmm0,%xmm15
    VPCOMLTUW      %xmm0,%xmm15,%xmm7
    VPCOMLTUW      %xmm0,%xmm0,%xmm0
    VPCOMLTW       %xmm0,%xmm11,%xmm0
    VPCOMLTW       0x6(%r9,%r11,2),%xmm11,%xmm15
    VPCOMLTW       %xmm15,%xmm11,%xmm15
    VPCOMLTW       (%r12),%xmm11,%xmm7
    VPCOMLTW       (%r12),%xmm15,%xmm7
    VPCOMLTW       0x6(%r9,%r11,2),%xmm15,%xmm0
    VPCOMLTW       (%rdi,%rcx),%xmm11,%xmm7
    VPCOMLTW       %xmm8,%xmm11,%xmm7
    VPCOMLEB       %xmm0,%xmm11,%xmm7
    VPCOMLEB       0x6(%r9,%r11,2),%xmm0,%xmm15
    VPCOMLEB       %xmm0,%xmm0,%xmm15
    VPCOMLEB       %xmm15,%xmm0,%xmm15
    VPCOMLEB       (%r12),%xmm11,%xmm7
    VPCOMLEB       %xmm15,%xmm11,%xmm7
    VPCOMLEB       (%rbx,%rax,4),%xmm11,%xmm15
    VPCOMLEB       (%r12),%xmm15,%xmm15
    VPCOMLED       (%r12),%xmm0,%xmm15
    VPCOMLED       %xmm8,%xmm11,%xmm15
    VPCOMLED       0x6(%r9,%r11,2),%xmm0,%xmm0
    VPCOMLED       %xmm0,%xmm15,%xmm7
    VPCOMLED       %xmm15,%xmm15,%xmm15
    VPCOMLED       0x6(%r9,%r11,2),%xmm0,%xmm7
    VPCOMLED       (%rbx,%rax,4),%xmm11,%xmm7
    VPCOMLED       (%rdi,%rcx),%xmm0,%xmm0
    VPCOMLEQ       0x6(%r9,%r11,2),%xmm0,%xmm15
    VPCOMLEQ       %xmm0,%xmm0,%xmm15
    VPCOMLEQ       %xmm15,%xmm11,%xmm0
    VPCOMLEQ       %xmm8,%xmm11,%xmm0
    VPCOMLEQ       %xmm8,%xmm0,%xmm0
    VPCOMLEQ       %xmm8,%xmm15,%xmm7
    VPCOMLEQ       %xmm0,%xmm11,%xmm7
    VPCOMLEQ       %xmm15,%xmm0,%xmm0
    VPCOMLEUB      (%rdi,%rcx),%xmm15,%xmm7
    VPCOMLEUB      0x6(%r9,%r11,2),%xmm11,%xmm0
    VPCOMLEUB      (%rbx,%rax,4),%xmm0,%xmm15
    VPCOMLEUB      0x6(%r9,%r11,2),%xmm0,%xmm7
    VPCOMLEUB      (%rbx,%rax,4),%xmm0,%xmm7
    VPCOMLEUB      (%r12),%xmm11,%xmm7
    VPCOMLEUB      %xmm0,%xmm15,%xmm0
    VPCOMLEUB      (%rbx,%rax,4),%xmm11,%xmm15
    VPCOMLEUD      (%rbx,%rax,4),%xmm15,%xmm15
    VPCOMLEUD      %xmm15,%xmm15,%xmm0
    VPCOMLEUD      %xmm15,%xmm0,%xmm0
    VPCOMLEUD      (%rbx,%rax,4),%xmm0,%xmm7
    VPCOMLEUD      %xmm8,%xmm11,%xmm7
    VPCOMLEUD      (%rbx,%rax,4),%xmm0,%xmm0
    VPCOMLEUD      0x6(%r9,%r11,2),%xmm15,%xmm0
    VPCOMLEUD      0x6(%r9,%r11,2),%xmm0,%xmm15
    VPCOMLEUQ      %xmm8,%xmm11,%xmm15
    VPCOMLEUQ      (%rbx,%rax,4),%xmm0,%xmm15
    VPCOMLEUQ      %xmm15,%xmm0,%xmm15
    VPCOMLEUQ      %xmm15,%xmm15,%xmm7
    VPCOMLEUQ      %xmm15,%xmm11,%xmm0
    VPCOMLEUQ      (%rbx,%rax,4),%xmm0,%xmm7
    VPCOMLEUQ      0x6(%r9,%r11,2),%xmm15,%xmm15
    VPCOMLEUQ      %xmm8,%xmm0,%xmm7
    VPCOMLEUW      0x6(%r9,%r11,2),%xmm11,%xmm15
    VPCOMLEUW      0x6(%r9,%r11,2),%xmm11,%xmm0
    VPCOMLEUW      %xmm8,%xmm15,%xmm0
    VPCOMLEUW      (%rbx,%rax,4),%xmm15,%xmm0
    VPCOMLEUW      %xmm0,%xmm0,%xmm15
    VPCOMLEUW      (%r12),%xmm0,%xmm7
    VPCOMLEUW      %xmm8,%xmm0,%xmm0
    VPCOMLEUW      (%rbx,%rax,4),%xmm11,%xmm7
    VPCOMLEW       (%rdi,%rcx),%xmm15,%xmm15
    VPCOMLEW       %xmm0,%xmm15,%xmm7
    VPCOMLEW       (%rbx,%rax,4),%xmm15,%xmm0
    VPCOMLEW       %xmm8,%xmm11,%xmm0
    VPCOMLEW       (%rdi,%rcx),%xmm15,%xmm7
    VPCOMLEW       (%rdi,%rcx),%xmm11,%xmm15
    VPCOMLEW       %xmm8,%xmm0,%xmm0
    VPCOMLEW       (%r12),%xmm11,%xmm7
    VPCOMGTB       (%r12),%xmm15,%xmm15
    VPCOMGTB       (%rbx,%rax,4),%xmm15,%xmm15
    VPCOMGTB       (%r12),%xmm11,%xmm15
    VPCOMGTB       %xmm15,%xmm15,%xmm0
    VPCOMGTB       %xmm8,%xmm15,%xmm0
    VPCOMGTB       (%rbx,%rax,4),%xmm11,%xmm7
    VPCOMGTB       %xmm8,%xmm11,%xmm15
    VPCOMGTB       %xmm8,%xmm15,%xmm15
    VPCOMGTD       (%rdi,%rcx),%xmm15,%xmm15
    VPCOMGTD       %xmm15,%xmm11,%xmm15
    VPCOMGTD       %xmm8,%xmm0,%xmm7
    VPCOMGTD       0x6(%r9,%r11,2),%xmm11,%xmm0
    VPCOMGTD       (%rbx,%rax,4),%xmm11,%xmm15
    VPCOMGTD       %xmm8,%xmm0,%xmm0
    VPCOMGTD       (%rdi,%rcx),%xmm11,%xmm0
    VPCOMGTD       %xmm15,%xmm0,%xmm0
    VPCOMGTQ       %xmm15,%xmm0,%xmm7
    VPCOMGTQ       %xmm8,%xmm0,%xmm0
    VPCOMGTQ       (%rdi,%rcx),%xmm15,%xmm7
    VPCOMGTQ       (%r12),%xmm0,%xmm7
    VPCOMGTQ       %xmm15,%xmm15,%xmm7
    VPCOMGTQ       (%rdi,%rcx),%xmm11,%xmm15
    VPCOMGTQ       %xmm0,%xmm15,%xmm15
    VPCOMGTQ       (%r12),%xmm11,%xmm15
    VPCOMGTUB      %xmm8,%xmm15,%xmm15
    VPCOMGTUB      %xmm8,%xmm11,%xmm0
    VPCOMGTUB      (%rbx,%rax,4),%xmm0,%xmm15
    VPCOMGTUB      (%r12),%xmm0,%xmm15
    VPCOMGTUB      (%rbx,%rax,4),%xmm11,%xmm7
    VPCOMGTUB      %xmm8,%xmm15,%xmm0
    VPCOMGTUB      %xmm15,%xmm15,%xmm15
    VPCOMGTUB      0x6(%r9,%r11,2),%xmm15,%xmm0
    VPCOMGTUD      (%r12),%xmm15,%xmm0
    VPCOMGTUD      %xmm15,%xmm11,%xmm15
    VPCOMGTUD      %xmm15,%xmm0,%xmm0
    VPCOMGTUD      0x6(%r9,%r11,2),%xmm0,%xmm15
    VPCOMGTUD      (%rbx,%rax,4),%xmm11,%xmm0
    VPCOMGTUD      %xmm0,%xmm0,%xmm0
    VPCOMGTUD      (%rdi,%rcx),%xmm0,%xmm0
    VPCOMGTUD      %xmm8,%xmm15,%xmm15
    VPCOMGTUQ      %xmm15,%xmm15,%xmm7
    VPCOMGTUQ      (%rbx,%rax,4),%xmm11,%xmm7
    VPCOMGTUQ      (%r12),%xmm11,%xmm0
    VPCOMGTUQ      0x6(%r9,%r11,2),%xmm11,%xmm15
    VPCOMGTUQ      %xmm8,%xmm11,%xmm15
    VPCOMGTUQ      %xmm0,%xmm0,%xmm0
    VPCOMGTUQ      %xmm0,%xmm15,%xmm15
    VPCOMGTUQ      (%r12),%xmm11,%xmm15
    VPCOMGTUW      (%rdi,%rcx),%xmm0,%xmm0
    VPCOMGTUW      0x6(%r9,%r11,2),%xmm11,%xmm0
    VPCOMGTUW      %xmm15,%xmm11,%xmm0
    VPCOMGTUW      (%r12),%xmm0,%xmm15
    VPCOMGTUW      %xmm0,%xmm15,%xmm7
    VPCOMGTUW      %xmm15,%xmm0,%xmm7
    VPCOMGTUW      %xmm15,%xmm11,%xmm7
    VPCOMGTUW      %xmm15,%xmm15,%xmm7
    VPCOMGTW       %xmm8,%xmm0,%xmm0
    VPCOMGTW       (%rbx,%rax,4),%xmm15,%xmm15
    VPCOMGTW       %xmm15,%xmm0,%xmm7
    VPCOMGTW       %xmm15,%xmm15,%xmm7
    VPCOMGTW       (%rbx,%rax,4),%xmm0,%xmm15
    VPCOMGTW       (%r12),%xmm15,%xmm7
    VPCOMGTW       0x6(%r9,%r11,2),%xmm11,%xmm7
    VPCOMGTW       (%rdi,%rcx),%xmm11,%xmm15
    VPCOMGEB       (%rbx,%rax,4),%xmm15,%xmm0
    VPCOMGEB       0x6(%r9,%r11,2),%xmm0,%xmm7
    VPCOMGEB       (%rdi,%rcx),%xmm15,%xmm15
    VPCOMGEB       (%rdi,%rcx),%xmm15,%xmm7
    VPCOMGEB       %xmm15,%xmm0,%xmm15
    VPCOMGEB       %xmm15,%xmm11,%xmm15
    VPCOMGEB       %xmm0,%xmm11,%xmm15
    VPCOMGEB       %xmm8,%xmm15,%xmm0
    VPCOMGED       %xmm15,%xmm11,%xmm15
    VPCOMGED       %xmm0,%xmm15,%xmm7
    VPCOMGED       (%rbx,%rax,4),%xmm0,%xmm7
    VPCOMGED       %xmm15,%xmm0,%xmm0
    VPCOMGED       %xmm15,%xmm0,%xmm15
    VPCOMGED       (%rdi,%rcx),%xmm11,%xmm15
    VPCOMGED       (%rbx,%rax,4),%xmm11,%xmm15
    VPCOMGED       %xmm8,%xmm0,%xmm15
    VPCOMGEQ       %xmm8,%xmm11,%xmm7
    VPCOMGEQ       %xmm15,%xmm15,%xmm7
    VPCOMGEQ       %xmm8,%xmm15,%xmm7
    VPCOMGEQ       %xmm15,%xmm11,%xmm0
    VPCOMGEQ       0x6(%r9,%r11,2),%xmm11,%xmm0
    VPCOMGEQ       0x6(%r9,%r11,2),%xmm15,%xmm0
    VPCOMGEQ       %xmm15,%xmm11,%xmm15
    VPCOMGEQ       (%rbx,%rax,4),%xmm15,%xmm0
    VPCOMGEUB      (%r12),%xmm15,%xmm7
    VPCOMGEUB      0x6(%r9,%r11,2),%xmm11,%xmm15
    VPCOMGEUB      (%r12),%xmm15,%xmm0
    VPCOMGEUB      (%rbx,%rax,4),%xmm15,%xmm0
    VPCOMGEUB      0x6(%r9,%r11,2),%xmm15,%xmm7
    VPCOMGEUB      %xmm0,%xmm0,%xmm7
    VPCOMGEUB      %xmm0,%xmm15,%xmm0
    VPCOMGEUB      %xmm15,%xmm11,%xmm7
    VPCOMGEUD      %xmm15,%xmm0,%xmm7
    VPCOMGEUD      (%rdi,%rcx),%xmm15,%xmm15
    VPCOMGEUD      (%rbx,%rax,4),%xmm11,%xmm0
    VPCOMGEUD      (%rbx,%rax,4),%xmm15,%xmm0
    VPCOMGEUD      %xmm0,%xmm11,%xmm15
    VPCOMGEUD      %xmm8,%xmm0,%xmm15
    VPCOMGEUD      (%r12),%xmm15,%xmm0
    VPCOMGEUD      (%rdi,%rcx),%xmm0,%xmm0
    VPCOMGEUQ      %xmm8,%xmm15,%xmm0
    VPCOMGEUQ      (%r12),%xmm11,%xmm15
    VPCOMGEUQ      %xmm15,%xmm0,%xmm7
    VPCOMGEUQ      %xmm0,%xmm11,%xmm15
    VPCOMGEUQ      (%rdi,%rcx),%xmm0,%xmm0
    VPCOMGEUQ      %xmm0,%xmm11,%xmm7
    VPCOMGEUQ      (%r12),%xmm0,%xmm0
    VPCOMGEUQ      0x6(%r9,%r11,2),%xmm15,%xmm7
    VPCOMGEUW      %xmm8,%xmm15,%xmm15
    VPCOMGEUW      %xmm15,%xmm0,%xmm7
    VPCOMGEUW      0x6(%r9,%r11,2),%xmm15,%xmm7
    VPCOMGEUW      %xmm0,%xmm11,%xmm7
    VPCOMGEUW      (%r12),%xmm15,%xmm15
    VPCOMGEUW      (%rdi,%rcx),%xmm11,%xmm7
    VPCOMGEUW      %xmm15,%xmm15,%xmm0
    VPCOMGEUW      %xmm8,%xmm15,%xmm7
    VPCOMGEW       (%rbx,%rax,4),%xmm0,%xmm15
    VPCOMGEW       %xmm0,%xmm0,%xmm0
    VPCOMGEW       %xmm0,%xmm15,%xmm7
    VPCOMGEW       %xmm0,%xmm0,%xmm15
    VPCOMGEW       0x6(%r9,%r11,2),%xmm11,%xmm15
    VPCOMGEW       %xmm0,%xmm0,%xmm7
    VPCOMGEW       (%rbx,%rax,4),%xmm15,%xmm15
    VPCOMGEW       (%rbx,%rax,4),%xmm0,%xmm0
    VPCOMEQB       (%r12),%xmm11,%xmm15
    VPCOMEQB       (%r12),%xmm15,%xmm7
    VPCOMEQB       %xmm15,%xmm11,%xmm7
    VPCOMEQB       %xmm0,%xmm15,%xmm0
    VPCOMEQB       0x6(%r9,%r11,2),%xmm0,%xmm7
    VPCOMEQB       %xmm0,%xmm15,%xmm7
    VPCOMEQB       (%rdi,%rcx),%xmm0,%xmm7
    VPCOMEQB       0x6(%r9,%r11,2),%xmm11,%xmm15
    VPCOMEQD       %xmm15,%xmm11,%xmm0
    VPCOMEQD       %xmm8,%xmm0,%xmm0
    VPCOMEQD       (%rbx,%rax,4),%xmm0,%xmm0
    VPCOMEQD       %xmm8,%xmm11,%xmm7
    VPCOMEQD       %xmm8,%xmm0,%xmm7
    VPCOMEQD       (%r12),%xmm0,%xmm7
    VPCOMEQD       0x6(%r9,%r11,2),%xmm0,%xmm0
    VPCOMEQD       0x6(%r9,%r11,2),%xmm15,%xmm15
    VPCOMEQQ       %xmm8,%xmm0,%xmm7
    VPCOMEQQ       %xmm8,%xmm0,%xmm15
    VPCOMEQQ       0x6(%r9,%r11,2),%xmm15,%xmm0
    VPCOMEQQ       (%rbx,%rax,4),%xmm15,%xmm7
    VPCOMEQQ       (%r12),%xmm0,%xmm15
    VPCOMEQQ       %xmm8,%xmm11,%xmm7
    VPCOMEQQ       %xmm15,%xmm15,%xmm15
    VPCOMEQQ       0x6(%r9,%r11,2),%xmm0,%xmm15
    VPCOMEQUB      %xmm0,%xmm0,%xmm15
    VPCOMEQUB      %xmm15,%xmm11,%xmm7
    VPCOMEQUB      %xmm0,%xmm11,%xmm0
    VPCOMEQUB      (%r12),%xmm0,%xmm0
    VPCOMEQUB      (%r12),%xmm15,%xmm15
    VPCOMEQUB      (%rbx,%rax,4),%xmm0,%xmm7
    VPCOMEQUB      (%r12),%xmm11,%xmm0
    VPCOMEQUB      %xmm8,%xmm15,%xmm7
    VPCOMEQUD      (%rbx,%rax,4),%xmm0,%xmm7
    VPCOMEQUD      0x6(%r9,%r11,2),%xmm15,%xmm15
    VPCOMEQUD      (%rbx,%rax,4),%xmm15,%xmm0
    VPCOMEQUD      (%rbx,%rax,4),%xmm0,%xmm15
    VPCOMEQUD      %xmm15,%xmm11,%xmm0
    VPCOMEQUD      (%rbx,%rax,4),%xmm15,%xmm15
    VPCOMEQUD      (%r12),%xmm11,%xmm7
    VPCOMEQUD      (%r12),%xmm0,%xmm7
    VPCOMEQUQ      (%r12),%xmm0,%xmm15
    VPCOMEQUQ      %xmm15,%xmm0,%xmm7
    VPCOMEQUQ      (%r12),%xmm11,%xmm15
    VPCOMEQUQ      (%rdi,%rcx),%xmm0,%xmm7
    VPCOMEQUQ      %xmm0,%xmm15,%xmm15
    VPCOMEQUQ      %xmm15,%xmm0,%xmm0
    VPCOMEQUQ      (%rdi,%rcx),%xmm11,%xmm7
    VPCOMEQUQ      %xmm0,%xmm0,%xmm7
    VPCOMEQUW      (%rdi,%rcx),%xmm15,%xmm15
    VPCOMEQUW      %xmm15,%xmm11,%xmm7
    VPCOMEQUW      0x6(%r9,%r11,2),%xmm0,%xmm15
    VPCOMEQUW      (%rdi,%rcx),%xmm0,%xmm15
    VPCOMEQUW      (%r12),%xmm15,%xmm0
    VPCOMEQUW      %xmm8,%xmm0,%xmm0
    VPCOMEQUW      (%r12),%xmm0,%xmm15
    VPCOMEQUW      (%rbx,%rax,4),%xmm0,%xmm15
    VPCOMEQW       0x6(%r9,%r11,2),%xmm11,%xmm7
    VPCOMEQW       %xmm0,%xmm15,%xmm0
    VPCOMEQW       %xmm15,%xmm11,%xmm0
    VPCOMEQW       %xmm0,%xmm0,%xmm7
    VPCOMEQW       (%rbx,%rax,4),%xmm0,%xmm15
    VPCOMEQW       (%rbx,%rax,4),%xmm15,%xmm7
    VPCOMEQW       %xmm15,%xmm0,%xmm0
    VPCOMEQW       (%rbx,%rax,4),%xmm15,%xmm15
    VPCOMNEQB      (%r12),%xmm11,%xmm15
    VPCOMNEQB      0x6(%r9,%r11,2),%xmm11,%xmm7
    VPCOMNEQB      %xmm0,%xmm0,%xmm0
    VPCOMNEQB      (%r12),%xmm0,%xmm7
    VPCOMNEQB      (%rbx,%rax,4),%xmm0,%xmm15
    VPCOMNEQB      (%rbx,%rax,4),%xmm15,%xmm15
    VPCOMNEQB      (%r12),%xmm11,%xmm0
    VPCOMNEQB      %xmm8,%xmm11,%xmm7
    VPCOMNEQD      (%rbx,%rax,4),%xmm15,%xmm7
    VPCOMNEQD      %xmm8,%xmm0,%xmm15
    VPCOMNEQD      %xmm8,%xmm15,%xmm0
    VPCOMNEQD      0x6(%r9,%r11,2),%xmm0,%xmm7
    VPCOMNEQD      %xmm15,%xmm11,%xmm0
    VPCOMNEQD      (%rdi,%rcx),%xmm0,%xmm0
    VPCOMNEQD      (%r12),%xmm0,%xmm0
    VPCOMNEQD      %xmm8,%xmm0,%xmm7
    VPCOMNEQQ      (%r12),%xmm0,%xmm15
    VPCOMNEQQ      %xmm8,%xmm15,%xmm0
    VPCOMNEQQ      (%rdi,%rcx),%xmm11,%xmm7
    VPCOMNEQQ      0x6(%r9,%r11,2),%xmm0,%xmm7
    VPCOMNEQQ      %xmm0,%xmm0,%xmm15
    VPCOMNEQQ      %xmm0,%xmm11,%xmm15
    VPCOMNEQQ      %xmm0,%xmm0,%xmm0
    VPCOMNEQQ      (%rbx,%rax,4),%xmm11,%xmm15
    VPCOMNEQUB     (%rdi,%rcx),%xmm11,%xmm15
    VPCOMNEQUB     (%rbx,%rax,4),%xmm0,%xmm0
    VPCOMNEQUB     %xmm15,%xmm11,%xmm7
    VPCOMNEQUB     %xmm8,%xmm11,%xmm15
    VPCOMNEQUB     %xmm0,%xmm0,%xmm0
    VPCOMNEQUB     0x6(%r9,%r11,2),%xmm15,%xmm0
    VPCOMNEQUB     %xmm8,%xmm15,%xmm15
    VPCOMNEQUB     %xmm15,%xmm0,%xmm7
    VPCOMNEQUD     (%rbx,%rax,4),%xmm11,%xmm15
    VPCOMNEQUD     (%r12),%xmm15,%xmm15
    VPCOMNEQUD     %xmm15,%xmm11,%xmm15
    VPCOMNEQUD     %xmm15,%xmm15,%xmm7
    VPCOMNEQUD     %xmm0,%xmm15,%xmm15
    VPCOMNEQUD     %xmm15,%xmm11,%xmm7
    VPCOMNEQUD     (%r12),%xmm0,%xmm15
    VPCOMNEQUD     (%r12),%xmm0,%xmm0
    VPCOMNEQUQ     0x6(%r9,%r11,2),%xmm15,%xmm7
    VPCOMNEQUQ     (%r12),%xmm0,%xmm7
    VPCOMNEQUQ     %xmm0,%xmm11,%xmm15
    VPCOMNEQUQ     (%rdi,%rcx),%xmm11,%xmm15
    VPCOMNEQUQ     (%rbx,%rax,4),%xmm15,%xmm15
    VPCOMNEQUQ     %xmm8,%xmm0,%xmm0
    VPCOMNEQUQ     (%r12),%xmm15,%xmm15
    VPCOMNEQUQ     %xmm15,%xmm15,%xmm15
    VPCOMNEQUW     %xmm15,%xmm0,%xmm7
    VPCOMNEQUW     %xmm8,%xmm0,%xmm7
    VPCOMNEQUW     %xmm15,%xmm15,%xmm7
    VPCOMNEQUW     %xmm8,%xmm11,%xmm7
    VPCOMNEQUW     %xmm8,%xmm0,%xmm15
    VPCOMNEQUW     (%rbx,%rax,4),%xmm15,%xmm15
    VPCOMNEQUW     0x6(%r9,%r11,2),%xmm11,%xmm15
    VPCOMNEQUW     %xmm15,%xmm0,%xmm15
    VPCOMNEQW      (%rbx,%rax,4),%xmm11,%xmm0
    VPCOMNEQW      (%r12),%xmm11,%xmm0
    VPCOMNEQW      %xmm15,%xmm11,%xmm0
    VPCOMNEQW      (%r12),%xmm15,%xmm15
    VPCOMNEQW      %xmm0,%xmm15,%xmm7
    VPCOMNEQW      %xmm0,%xmm0,%xmm15
    VPCOMNEQW      %xmm15,%xmm0,%xmm7
    VPCOMNEQW      (%rdi,%rcx),%xmm11,%xmm15
    VPCOMFALSEB    (%rdi,%rcx),%xmm11,%xmm15
    VPCOMFALSEB    %xmm0,%xmm15,%xmm7
    VPCOMFALSEB    (%r12),%xmm0,%xmm0
    VPCOMFALSEB    %xmm8,%xmm11,%xmm15
    VPCOMFALSEB    (%rbx,%rax,4),%xmm11,%xmm0
    VPCOMFALSEB    (%r12),%xmm15,%xmm0
    VPCOMFALSEB    (%r12),%xmm0,%xmm7
    VPCOMFALSEB    (%rdi,%rcx),%xmm15,%xmm15
    VPCOMFALSED    (%rdi,%rcx),%xmm11,%xmm15
    VPCOMFALSED    %xmm0,%xmm11,%xmm15
    VPCOMFALSED    0x6(%r9,%r11,2),%xmm0,%xmm15
    VPCOMFALSED    %xmm15,%xmm15,%xmm15
    VPCOMFALSED    %xmm0,%xmm11,%xmm0
    VPCOMFALSED    %xmm15,%xmm0,%xmm15
    VPCOMFALSED    %xmm0,%xmm11,%xmm7
    VPCOMFALSED    %xmm15,%xmm15,%xmm0
    VPCOMFALSEQ    %xmm15,%xmm15,%xmm7
    VPCOMFALSEQ    (%rdi,%rcx),%xmm0,%xmm15
    VPCOMFALSEQ    (%rbx,%rax,4),%xmm0,%xmm15
    VPCOMFALSEQ    (%r12),%xmm0,%xmm0
    VPCOMFALSEQ    %xmm0,%xmm0,%xmm0
    VPCOMFALSEQ    %xmm8,%xmm0,%xmm15
    VPCOMFALSEQ    %xmm15,%xmm11,%xmm7
    VPCOMFALSEQ    (%r12),%xmm0,%xmm7
    VPCOMFALSEUB   (%rdi,%rcx),%xmm11,%xmm0
    VPCOMFALSEUB   (%rbx,%rax,4),%xmm0,%xmm7
    VPCOMFALSEUB   (%rbx,%rax,4),%xmm11,%xmm0
    VPCOMFALSEUB   0x6(%r9,%r11,2),%xmm11,%xmm0
    VPCOMFALSEUB   %xmm15,%xmm15,%xmm7
    VPCOMFALSEUB   %xmm8,%xmm0,%xmm15
    VPCOMFALSEUB   (%rbx,%rax,4),%xmm11,%xmm7
    VPCOMFALSEUB   %xmm8,%xmm11,%xmm15
    VPCOMFALSEUD   0x6(%r9,%r11,2),%xmm11,%xmm0
    VPCOMFALSEUD   %xmm8,%xmm15,%xmm0
    VPCOMFALSEUD   0x6(%r9,%r11,2),%xmm11,%xmm7
    VPCOMFALSEUD   0x6(%r9,%r11,2),%xmm0,%xmm0
    VPCOMFALSEUD   %xmm0,%xmm0,%xmm15
    VPCOMFALSEUD   (%r12),%xmm15,%xmm0
    VPCOMFALSEUD   %xmm0,%xmm15,%xmm7
    VPCOMFALSEUD   %xmm15,%xmm0,%xmm7
    VPCOMFALSEUQ   %xmm15,%xmm0,%xmm15
    VPCOMFALSEUQ   %xmm15,%xmm0,%xmm7
    VPCOMFALSEUQ   (%r12),%xmm0,%xmm7
    VPCOMFALSEUQ   %xmm0,%xmm0,%xmm0
    VPCOMFALSEUQ   (%rdi,%rcx),%xmm0,%xmm15
    VPCOMFALSEUQ   0x6(%r9,%r11,2),%xmm11,%xmm7
    VPCOMFALSEUQ   (%rdi,%rcx),%xmm11,%xmm0
    VPCOMFALSEUQ   %xmm0,%xmm15,%xmm7
    VPCOMFALSEUW   %xmm0,%xmm0,%xmm0
    VPCOMFALSEUW   (%r12),%xmm11,%xmm7
    VPCOMFALSEUW   (%rdi,%rcx),%xmm15,%xmm15
    VPCOMFALSEUW   %xmm8,%xmm15,%xmm0
    VPCOMFALSEUW   (%rdi,%rcx),%xmm11,%xmm7
    VPCOMFALSEUW   %xmm15,%xmm11,%xmm0
    VPCOMFALSEUW   0x6(%r9,%r11,2),%xmm15,%xmm7
    VPCOMFALSEUW   (%rdi,%rcx),%xmm11,%xmm0
    VPCOMFALSEW    0x6(%r9,%r11,2),%xmm11,%xmm0
    VPCOMFALSEW    0x6(%r9,%r11,2),%xmm0,%xmm15
    VPCOMFALSEW    0x6(%r9,%r11,2),%xmm0,%xmm7
    VPCOMFALSEW    0x6(%r9,%r11,2),%xmm11,%xmm7
    VPCOMFALSEW    %xmm15,%xmm15,%xmm15
    VPCOMFALSEW    %xmm8,%xmm11,%xmm7
    VPCOMFALSEW    (%rbx,%rax,4),%xmm0,%xmm0
    VPCOMFALSEW    (%r12),%xmm15,%xmm0
    VPCOMTRUEB     (%rbx,%rax,4),%xmm15,%xmm7
    VPCOMTRUEB     (%r12),%xmm0,%xmm7
    VPCOMTRUEB     %xmm0,%xmm15,%xmm7
    VPCOMTRUEB     (%rdi,%rcx),%xmm15,%xmm0
    VPCOMTRUEB     %xmm15,%xmm15,%xmm0
    VPCOMTRUEB     (%r12),%xmm15,%xmm0
    VPCOMTRUEB     %xmm15,%xmm11,%xmm15
    VPCOMTRUEB     (%rdi,%rcx),%xmm11,%xmm7
    VPCOMTRUED     (%r12),%xmm11,%xmm0
    VPCOMTRUED     (%r12),%xmm11,%xmm15
    VPCOMTRUED     %xmm15,%xmm11,%xmm0
    VPCOMTRUED     0x6(%r9,%r11,2),%xmm0,%xmm7
    VPCOMTRUED     %xmm0,%xmm15,%xmm7
    VPCOMTRUED     %xmm0,%xmm11,%xmm7
    VPCOMTRUED     (%rbx,%rax,4),%xmm15,%xmm7
    VPCOMTRUED     (%r12),%xmm0,%xmm7
    VPCOMTRUEQ     %xmm15,%xmm0,%xmm7
    VPCOMTRUEQ     (%r12),%xmm15,%xmm7
    VPCOMTRUEQ     %xmm0,%xmm15,%xmm7
    VPCOMTRUEQ     0x6(%r9,%r11,2),%xmm0,%xmm15
    VPCOMTRUEQ     %xmm15,%xmm11,%xmm0
    VPCOMTRUEQ     %xmm0,%xmm11,%xmm15
    VPCOMTRUEQ     (%rdi,%rcx),%xmm15,%xmm0
    VPCOMTRUEQ     0x6(%r9,%r11,2),%xmm11,%xmm7
    VPCOMTRUEUB    %xmm0,%xmm15,%xmm15
    VPCOMTRUEUB    %xmm8,%xmm0,%xmm0
    VPCOMTRUEUB    %xmm15,%xmm0,%xmm0
    VPCOMTRUEUB    (%r12),%xmm15,%xmm7
    VPCOMTRUEUB    (%r12),%xmm0,%xmm7
    VPCOMTRUEUB    %xmm0,%xmm11,%xmm15
    VPCOMTRUEUB    0x6(%r9,%r11,2),%xmm11,%xmm0
    VPCOMTRUEUB    %xmm15,%xmm11,%xmm15
    VPCOMTRUEUD    %xmm15,%xmm15,%xmm15
    VPCOMTRUEUD    0x6(%r9,%r11,2),%xmm11,%xmm15
    VPCOMTRUEUD    %xmm0,%xmm15,%xmm15
    VPCOMTRUEUD    %xmm8,%xmm11,%xmm0
    VPCOMTRUEUD    0x6(%r9,%r11,2),%xmm0,%xmm0
    VPCOMTRUEUD    (%rbx,%rax,4),%xmm15,%xmm15
    VPCOMTRUEUD    %xmm15,%xmm0,%xmm7
    VPCOMTRUEUD    (%rdi,%rcx),%xmm15,%xmm15
    VPCOMTRUEUQ    (%rdi,%rcx),%xmm0,%xmm0
    VPCOMTRUEUQ    (%rbx,%rax,4),%xmm15,%xmm15
    VPCOMTRUEUQ    (%r12),%xmm11,%xmm0
    VPCOMTRUEUQ    (%rbx,%rax,4),%xmm0,%xmm7
    VPCOMTRUEUQ    %xmm8,%xmm11,%xmm15
    VPCOMTRUEUQ    0x6(%r9,%r11,2),%xmm0,%xmm0
    VPCOMTRUEUQ    %xmm8,%xmm15,%xmm15
    VPCOMTRUEUQ    (%r12),%xmm15,%xmm15
    VPCOMTRUEUW    %xmm8,%xmm15,%xmm15
    VPCOMTRUEUW    0x6(%r9,%r11,2),%xmm15,%xmm7
    VPCOMTRUEUW    (%r12),%xmm11,%xmm15
    VPCOMTRUEUW    (%rbx,%rax,4),%xmm11,%xmm15
    VPCOMTRUEUW    %xmm0,%xmm15,%xmm15
    VPCOMTRUEUW    %xmm8,%xmm0,%xmm7
    VPCOMTRUEUW    (%rbx,%rax,4),%xmm0,%xmm7
    VPCOMTRUEUW    (%rbx,%rax,4),%xmm15,%xmm7
    VPCOMTRUEW     (%r12),%xmm11,%xmm0
    VPCOMTRUEW     %xmm15,%xmm15,%xmm15
    VPCOMTRUEW     %xmm15,%xmm11,%xmm15
    VPCOMTRUEW     (%rbx,%rax,4),%xmm11,%xmm15
    VPCOMTRUEW     (%r12),%xmm15,%xmm7
    VPCOMTRUEW     %xmm8,%xmm15,%xmm0
    VPCOMTRUEW     %xmm0,%xmm0,%xmm7
    VPCOMTRUEW     (%rbx,%rax,4),%xmm0,%xmm15
