.text
fcmpzhss  vr0
fcmpzlss  vr1
fcmpznes  vr5
fcmpzuos  vr8
fcmpzhsd  vr10
fcmpzlsd  vr13
fcmpzned  vr14
fcmpzuod  vr15
fmovs     vr12, fr9
fabss     vr1,  fr0
fnegs     vr2,  fr1
fcmphss   vr7,  fr2
fcmplts   vr6,  fr3
fcmpnes   vr2,  fr4
fcmpuos   vr12, fr5
frecips   vr11, fr6
fsqrts    vr10, fr7
fmovd     vr9,  fr8
fabsd     vr13, fr9
fnegd     vr14, fr10
fcmphsd   vr15, fr11
fcmpltd   vr0,  fr12
fcmpned   vr3,  fr13
fcmpuod   vr4,  fr14
frecipd   vr5,  fr15
fsqrtd    vr8,  fr8
fmovm     vr1,  fr3
fabsm     vr3,  fr13
fnegm     vr15, fr2
fstosi.rn  vr15, vr2
fstosi.rz  vr14, vr2
fstosi.rpi vr13, vr15
fstosi.rni vr12, vr14
fstoui.rn  vr11, fr13
fstoui.rz  vr10, fr12
fstoui.rpi vr9, fr11
fstoui.rni fr8, vr10
fdtosi.rn  fr7, vr9
fdtosi.rz  fr6, vr8
fdtosi.rpi fr5, vr7
fdtosi.rni fr4, vr6
fdtoui.rn  fr3, fr5
fdtoui.rz  fr2, fr4
fdtoui.rpi fr1, fr3
fdtoui.rni fr0, fr2
fsitos   vr14, vr1
fuitos   fr12, vr0
fsitod   fr13, fr2
fuitod   fr11, fr4
fdtos    vr2, vr8
fstod    fr5, vr11
