# Ensure that GNU syntax is accepted even for XCOFF.
  .internal internal
  .hidden hidden
  .protected protected

# Ensure that only the last visibility is taken into
# account, when several are provided.
  .protected dual
  .internal dual
