.*Assembler messages:
.*Error: unrecognized opcode `r,0x00000013'
.*Error: values must be constant `0x4,rs1'
.*Error: unrecognized values `0x4 0x5'
.*Error: unrecognized values `0x4,0x5,0x6'
.*Error: value conflicts with instruction length `0x4,0x0001'
.*Error: value conflicts with instruction length `0x2,0x00000013'
.*Error: value conflicts with instruction length `0x10+1f'
.*Error: value conflicts with instruction length `6,0x10+1f'
.*Error: value conflicts with instruction length `0x10+3f'
.*Error: value conflicts with instruction length `8,0x10+3f'
.*Error: value conflicts with instruction length `0x10+7f'
.*Error: value conflicts with instruction length `10,0x10+7f'
.*Error: value conflicts with instruction length `0x10+107f'
.*Error: value conflicts with instruction length `12,0x10+107f'
.*Error: value conflicts with instruction length `0x10+607f'
.*Error: value conflicts with instruction length `22,0x10+607f'
