# Check AVX2 WIG instructions

	.text
_start:
	vmovntdqa (%rcx),%ymm4
	vmpsadbw $7,%ymm4,%ymm6,%ymm2
	vpabsb %ymm4,%ymm6
	vpabsd %ymm4,%ymm6
	vpabsw %ymm4,%ymm6
	vpackssdw %ymm4,%ymm6,%ymm2
	vpacksswb %ymm4,%ymm6,%ymm2
	vpackusdw %ymm4,%ymm6,%ymm2
	vpackuswb %ymm4,%ymm6,%ymm2
	vpaddb %ymm4,%ymm6,%ymm2
	vpaddd %ymm4,%ymm6,%ymm2
	vpaddq %ymm4,%ymm6,%ymm2
	vpaddsb %ymm4,%ymm6,%ymm2
	vpaddsw %ymm4,%ymm6,%ymm2
	vpaddusb %ymm4,%ymm6,%ymm2
	vpaddusw %ymm4,%ymm6,%ymm2
	vpaddw %ymm4,%ymm6,%ymm2
	vpalignr $7,%ymm4,%ymm6,%ymm2
	vpand %ymm4,%ymm6,%ymm2
	vpandn %ymm4,%ymm6,%ymm2
	vpavgb %ymm4,%ymm6,%ymm2
	vpavgw %ymm4,%ymm6,%ymm2
	vpblendw $7,%ymm4,%ymm6,%ymm2
	vpcmpeqb %ymm4,%ymm6,%ymm2
	vpcmpeqd %ymm4,%ymm6,%ymm2
	vpcmpeqq %ymm4,%ymm6,%ymm2
	vpcmpeqw %ymm4,%ymm6,%ymm2
	vpcmpgtb %ymm4,%ymm6,%ymm2
	vpcmpgtd %ymm4,%ymm6,%ymm2
	vpcmpgtq %ymm4,%ymm6,%ymm2
	vpcmpgtw %ymm4,%ymm6,%ymm2
	vphaddd %ymm4,%ymm6,%ymm2
	vphaddsw %ymm4,%ymm6,%ymm2
	vphaddw %ymm4,%ymm6,%ymm2
	vphsubd %ymm4,%ymm6,%ymm2
	vphsubsw %ymm4,%ymm6,%ymm2
	vphsubw %ymm4,%ymm6,%ymm2
	vpmaddubsw %ymm4,%ymm6,%ymm2
	vpmaddwd %ymm4,%ymm6,%ymm2
	vpmaxsb %ymm4,%ymm6,%ymm2
	vpmaxsd %ymm4,%ymm6,%ymm2
	vpmaxsw %ymm4,%ymm6,%ymm2
	vpmaxub %ymm4,%ymm6,%ymm2
	vpmaxud %ymm4,%ymm6,%ymm2
	vpmaxuw %ymm4,%ymm6,%ymm2
	vpminsb %ymm4,%ymm6,%ymm2
	vpminsd %ymm4,%ymm6,%ymm2
	vpminsw %ymm4,%ymm6,%ymm2
	vpminub %ymm4,%ymm6,%ymm2
	vpminud %ymm4,%ymm6,%ymm2
	vpminuw %ymm4,%ymm6,%ymm2
	vpmovmskb %ymm4,%ecx
	vpmovsxbd %xmm4,%ymm6
	vpmovsxbq %xmm4,%ymm4
	vpmovsxbw %xmm4,%ymm4
	vpmovsxdq %xmm4,%ymm4
	vpmovsxwd %xmm4,%ymm4
	vpmovsxwq %xmm4,%ymm6
	vpmovzxbd %xmm4,%ymm6
	vpmovzxbq %xmm4,%ymm4
	vpmovzxbw %xmm4,%ymm4
	vpmovzxdq %xmm4,%ymm4
	vpmovzxwd %xmm4,%ymm4
	vpmovzxwq %xmm4,%ymm6
	vpmuldq %ymm4,%ymm6,%ymm2
	vpmulhrsw %ymm4,%ymm6,%ymm2
	vpmulhuw %ymm4,%ymm6,%ymm2
	vpmulhw %ymm4,%ymm6,%ymm2
	vpmulld %ymm4,%ymm6,%ymm2
	vpmullw %ymm4,%ymm6,%ymm2
	vpmuludq %ymm4,%ymm6,%ymm2
	vpor %ymm4,%ymm6,%ymm2
	vpsadbw %ymm4,%ymm6,%ymm2
	vpshufb %ymm4,%ymm6,%ymm2
	vpshufd $7,%ymm6,%ymm2
	vpshufhw $7,%ymm6,%ymm2
	vpshuflw $7,%ymm6,%ymm2
	vpsignb %ymm4,%ymm6,%ymm2
	vpsignd %ymm4,%ymm6,%ymm2
	vpsignw %ymm4,%ymm6,%ymm2
	vpslld $7,%ymm6,%ymm2
	vpslldq $7,%ymm6,%ymm2
	vpsllq $7,%ymm6,%ymm2
	vpsllw $7,%ymm6,%ymm2
	vpsrad $7,%ymm6,%ymm2
	vpsraw $7,%ymm6,%ymm2
	vpsrld $7,%ymm6,%ymm2
	vpsrldq $7,%ymm6,%ymm2
	vpsrlq $7,%ymm6,%ymm2
	vpsrlw $7,%ymm6,%ymm2
	vpsubb %ymm4,%ymm6,%ymm2
	vpsubd %ymm4,%ymm6,%ymm2
	vpsubq %ymm4,%ymm6,%ymm2
	vpsubsb %ymm4,%ymm6,%ymm2
	vpsubsw %ymm4,%ymm6,%ymm2
	vpsubusb %ymm4,%ymm6,%ymm2
	vpsubusw %ymm4,%ymm6,%ymm2
	vpsubw %ymm4,%ymm6,%ymm2
	vpunpckhbw %ymm4,%ymm6,%ymm2
	vpunpckhdq %ymm4,%ymm6,%ymm2
	vpunpckhqdq %ymm4,%ymm6,%ymm2
	vpunpckhwd %ymm4,%ymm6,%ymm2
	vpunpcklbw %ymm4,%ymm6,%ymm2
	vpunpckldq %ymm4,%ymm6,%ymm2
	vpunpcklqdq %ymm4,%ymm6,%ymm2
	vpunpcklwd %ymm4,%ymm6,%ymm2
	vpxor %ymm4,%ymm6,%ymm2
