        .section ".data.aa.01", "aw"
        .word 0x1

        .section ".data.aa.02", "aw"
        .word 0x2

        .section ".data.aa.03", "aw"
        .word 0x3

        .section ".data.bb.01", "aw"
        .word 0x4

        .section ".data.bb.02", "aw"
        .word 0x5

        .section ".data.bb.03", "aw"
        .word 0x6
