fadd.s  $f0,$f1,$f2
fadd.d  $f0,$f1,$f2
fsub.s  $f0,$f1,$f2
fsub.d  $f0,$f1,$f2
fmul.s  $f0,$f1,$f2
fmul.d  $f0,$f1,$f2
fdiv.s  $f0,$f1,$f2
fdiv.d  $f0,$f1,$f2
fmax.s  $f0,$f1,$f2
fmax.d  $f0,$f1,$f2
fmin.s  $f0,$f1,$f2
fmin.d  $f0,$f1,$f2
fmaxa.s  $f0,$f1,$f2
fmaxa.d  $f0,$f1,$f2
fmina.s  $f0,$f1,$f2
fmina.d  $f0,$f1,$f2
fscaleb.s  $f0,$f1,$f2
fscaleb.d  $f0,$f1,$f2
fcopysign.s  $f0,$f1,$f2
fcopysign.d  $f0,$f1,$f2
fabs.s  $f0,$f1
fabs.d  $f0,$f1
fneg.s  $f0,$f1
fneg.d  $f0,$f1
flogb.s  $f0,$f1
flogb.d  $f0,$f1
fclass.s  $f0,$f1
fclass.d  $f0,$f1
fsqrt.s  $f0,$f1
fsqrt.d  $f0,$f1
frecip.s  $f0,$f1
frecip.d  $f0,$f1
frsqrt.s  $f0,$f1
frsqrt.d  $f0,$f1
fmov.s  $f0,$f1
fmov.d  $f0,$f1
movgr2fr.w  $f0,$r5
movgr2fr.d  $f0,$r5
movgr2frh.w  $f0,$r5
movfr2gr.s  $r4,$f1
movfr2gr.d  $r4,$f1
movfrh2gr.s  $r4,$f1
movgr2fcsr  $fcsr0,$r5
movfcsr2gr  $r4,$fcsr0
movfr2cf  $fcc0,$f1
movcf2fr  $f0,$fcc5
movgr2cf  $fcc0,$r5
movcf2gr  $r4,$fcc5
fcvt.s.d  $f0,$f1
fcvt.d.s  $f0,$f1
ftintrm.w.s  $f0,$f1
ftintrm.w.d  $f0,$f1
ftintrm.l.s  $f0,$f1
ftintrm.l.d  $f0,$f1
ftintrp.w.s  $f0,$f1
ftintrp.w.d  $f0,$f1
ftintrp.l.s  $f0,$f1
ftintrp.l.d  $f0,$f1
ftintrz.w.s  $f0,$f1
ftintrz.w.d  $f0,$f1
ftintrz.l.s  $f0,$f1
ftintrz.l.d  $f0,$f1
ftintrne.w.s  $f0,$f1
ftintrne.w.d  $f0,$f1
ftintrne.l.s  $f0,$f1
ftintrne.l.d  $f0,$f1
ftint.w.s  $f0,$f1
ftint.w.d  $f0,$f1
ftint.l.s  $f0,$f1
ftint.l.d  $f0,$f1
ffint.s.w  $f0,$f1
ffint.s.l  $f0,$f1
ffint.d.w  $f0,$f1
ffint.d.l  $f0,$f1
frint.s  $f0,$f1
frint.d  $f0,$f1
frecipe.s  $f0,$f1
frecipe.d  $f0,$f1
frsqrte.s  $f0,$f1
frsqrte.d  $f0,$f1

# 4_opt_op
fmadd.s  $f0,$f1,$f2,$f3
fmadd.d  $f0,$f1,$f2,$f3
fmsub.s  $f0,$f1,$f2,$f3
fmsub.d  $f0,$f1,$f2,$f3
fnmadd.s  $f0,$f1,$f2,$f3
fnmadd.d  $f0,$f1,$f2,$f3
fnmsub.s  $f0,$f1,$f2,$f3
fnmsub.d  $f0,$f1,$f2,$f3
fcmp.caf.s  $fcc0,$f1,$f2
fcmp.saf.s  $fcc0,$f1,$f2
fcmp.clt.s  $fcc0,$f1,$f2
fcmp.slt.s  $fcc0,$f1,$f2
fcmp.sgt.s  $fcc0,$f2,$f1
fcmp.ceq.s  $fcc0,$f1,$f2
fcmp.seq.s  $fcc0,$f1,$f2
fcmp.cle.s  $fcc0,$f1,$f2
fcmp.sle.s  $fcc0,$f1,$f2
fcmp.sge.s  $fcc0,$f2,$f1
fcmp.cun.s  $fcc0,$f1,$f2
fcmp.sun.s  $fcc0,$f1,$f2
fcmp.cult.s  $fcc0,$f1,$f2
fcmp.cugt.s  $fcc0,$f2,$f1
fcmp.sult.s  $fcc0,$f1,$f2
fcmp.cueq.s  $fcc0,$f1,$f2
fcmp.sueq.s  $fcc0,$f1,$f2
fcmp.cule.s  $fcc0,$f1,$f2
fcmp.cuge.s  $fcc0,$f2,$f1
fcmp.sule.s  $fcc0,$f1,$f2
fcmp.cne.s  $fcc0,$f1,$f2
fcmp.sne.s  $fcc0,$f1,$f2
fcmp.cor.s  $fcc0,$f1,$f2
fcmp.sor.s  $fcc0,$f1,$f2
fcmp.cune.s  $fcc0,$f1,$f2
fcmp.sune.s  $fcc0,$f1,$f2
fcmp.caf.d  $fcc0,$f1,$f2
fcmp.saf.d  $fcc0,$f1,$f2
fcmp.clt.d  $fcc0,$f1,$f2
fcmp.slt.d  $fcc0,$f1,$f2
fcmp.sgt.d  $fcc0,$f2,$f1
fcmp.ceq.d  $fcc0,$f1,$f2
fcmp.seq.d  $fcc0,$f1,$f2
fcmp.cle.d  $fcc0,$f1,$f2
fcmp.sle.d  $fcc0,$f1,$f2
fcmp.sge.d  $fcc0,$f2,$f1
fcmp.cun.d  $fcc0,$f1,$f2
fcmp.sun.d  $fcc0,$f1,$f2
fcmp.cult.d  $fcc0,$f1,$f2
fcmp.cugt.d  $fcc0,$f2,$f1
fcmp.sult.d  $fcc0,$f1,$f2
fcmp.cueq.d  $fcc0,$f1,$f2
fcmp.sueq.d  $fcc0,$f1,$f2
fcmp.cule.d  $fcc0,$f1,$f2
fcmp.cuge.d  $fcc0,$f2,$f1
fcmp.sule.d  $fcc0,$f1,$f2
fcmp.cne.d  $fcc0,$f1,$f2
fcmp.sne.d  $fcc0,$f1,$f2
fcmp.cor.d  $fcc0,$f1,$f2
fcmp.sor.d  $fcc0,$f1,$f2
fcmp.cune.d  $fcc0,$f1,$f2
fcmp.sune.d  $fcc0,$f1,$f2
fsel  $f0,$f1,$f2,$fcc0
fld.s $f10,$r12,1
fst.s $f10,$r12,1
fld.d $f10,$r12,1
fst.d $f10,$r12,1
fldgt.s	$f0,$a0,$a1
fldgt.d	$f0,$a0,$a1
fldle.s	$f0,$a0,$a1
fldle.d	$f0,$a0,$a1
fstgt.s	$f0,$a0,$a1
fstgt.d	$f0,$a0,$a1
fstle.s	$f0,$a0,$a1
fstle.d	$f0,$a0,$a1
bceqz  $fcc0,.L1
bcnez  $fcc0,.L1
