.*: Assembler messages:
.*: Error: illegal operands `cbo.clean 1\(x1\)'
.*: Error: illegal operands `cbo.clean x30'
.*: Error: illegal operands `cbo.flush \(0\+1\)\(x1\)'
.*: Error: illegal operands `cbo.flush x30'
.*: Error: illegal operands `cbo.inval 3\*2\+5\(x1\)'
.*: Error: illegal operands `cbo.inval x30'
