# objdump: -dr

.*: *file format elf32-h8300

Disassembly of section \.text:

0+00 <\.text>:
 *0:	54 00 *	rts/l	er0
 *2:	54 01 *	rts/l	er1
 *4:	54 03 *	rts/l	er3
 *6:	54 05 *	rts/l	er5
 *8:	54 16 *	rts/l	er5-er6
 *a:	54 25 *	rts/l	er3-er5
 *c:	54 34 *	rts/l	er1-er4
