.*: Assembler messages:
.*:14: Error: jump to a symbol in another ISA mode
.*:16: Error: jump to a symbol in another ISA mode
.*:18: Error: jump to misaligned address \(0x11e1\)
.*:20: Error: jump to misaligned address \(0x11e1\)
.*:22: Error: jump to a symbol in another ISA mode
.*:24: Error: jump to a symbol in another ISA mode
.*:26: Error: jump to misaligned address \(0x11e2\)
.*:28: Error: jump to misaligned address \(0x11e2\)
.*:30: Error: jump to a symbol in another ISA mode
.*:32: Error: jump to a symbol in another ISA mode
.*:34: Error: jump to misaligned address \(0x11e3\)
.*:36: Error: jump to misaligned address \(0x11e3\)
.*:38: Error: jump to a symbol in another ISA mode
.*:40: Error: jump to a symbol in another ISA mode
.*:46: Error: jump to a symbol in another ISA mode
.*:48: Error: jump to a symbol in another ISA mode
.*:50: Error: jump to misaligned address \(0x11e5\)
.*:52: Error: jump to misaligned address \(0x11e5\)
.*:54: Error: jump to a symbol in another ISA mode
.*:56: Error: jump to a symbol in another ISA mode
.*:58: Error: jump to misaligned address \(0x11e6\)
.*:60: Error: jump to misaligned address \(0x11e6\)
.*:62: Error: jump to a symbol in another ISA mode
.*:64: Error: jump to a symbol in another ISA mode
.*:66: Error: jump to misaligned address \(0x11e7\)
.*:68: Error: jump to misaligned address \(0x11e7\)
.*:70: Error: jump to a symbol in another ISA mode
.*:72: Error: jump to a symbol in another ISA mode
.*:78: Error: jump to a symbol in another ISA mode
.*:80: Error: jump to a symbol in another ISA mode
.*:82: Error: JALX to a symbol in the same ISA mode
.*:90: Error: JALX to a symbol in the same ISA mode
.*:98: Error: JALX to a symbol in the same ISA mode
.*:106: Error: JALX to a symbol in the same ISA mode
.*:108: Error: jump to misaligned address \(0x11f5\)
.*:110: Error: jump to misaligned address \(0x11f5\)
.*:112: Error: jump to misaligned address \(0x11f5\)
.*:114: Error: JALX to a symbol in the same ISA mode
.*:122: Error: JALX to a symbol in the same ISA mode
.*:124: Error: jump to misaligned address \(0x11f7\)
.*:126: Error: jump to misaligned address \(0x11f7\)
.*:128: Error: jump to misaligned address \(0x11f7\)
.*:130: Error: JALX to a symbol in the same ISA mode
