.* Assembler messages:
.*5: Error: invalid register operand size for `enqcmd'
.*6: Error: invalid register operand size for `enqcmd'
.*7: Error: invalid register operand size for `enqcmd'
.*8: Error: invalid register operand size for `enqcmd'
.*9: Error: invalid register operand size for `enqcmds'
.*10: Error: invalid register operand size for `enqcmds'
.*11: Error: invalid register operand size for `enqcmds'
.*12: Error: invalid register operand size for `enqcmds'
.*15: Error: invalid register operand size for `enqcmd'
.*16: Error: invalid register operand size for `enqcmd'
.*17: Error: invalid register operand size for `enqcmds'
.*18: Error: invalid register operand size for `enqcmds'
