	block[]
	br 0
	br_if 0
	br_table 1 1 1
	call 0
	call_indirect 0 0
	drop
	else
	end
	f32.abs
	f32.add
	f32.ceil
	f32.const 3.14159
	f32.convert_s/i32
	f32.convert_s/i64
	f32.convert_u/i32
	f32.convert_u/i64
	f32.copysign
	f32.demote/f64
	f32.div
	f32.eq
	f32.floor
	f32.ge
	f32.gt
	f32.le
	f32.load a=0 0
	f32.lt
	f32.max
	f32.min
	f32.mul
	f32.ne
	f32.nearest
	f32.neg
	f32.reinterpret/i32
	f32.sqrt
	f32.store a=0 0
	f32.sub
	f32.trunc
	f64.abs
	f64.add
	f64.ceil
	f64.const 3.14159e200
	f64.convert_s/i32
	f64.convert_s/i64
	f64.convert_u/i32
	f64.convert_u/i64
	f64.copysign
	f64.div
	f64.eq
	f64.floor
	f64.ge
	f64.gt
	f64.le
	f64.load a=0 0
	f64.lt
	f64.max
	f64.min
	f64.mul
	f64.ne
	f64.nearest
	f64.neg
	f64.promote/f32
	f64.reinterpret/i64
	f64.sqrt
	f64.store a=0 0
	f64.sub
	f64.trunc
	get_global 0
	get_local 0
	i32.add
	i32.and
	i32.clz
	i32.const 0xdeadbeef
	i32.ctz
	i32.div_s
	i32.div_u
	i32.eq
	i32.eqz
	i32.ge_s
	i32.ge_u
	i32.gt_s
	i32.gt_u
	i32.le_s
	i32.le_u
	i32.load a=0 0
	i32.load16_s a=0 0
	i32.load16_u a=0 0
	i32.load8_s a=0 0
	i32.load8_u a=0 0
	i32.lt_s
	i32.lt_u
	i32.mul
	i32.ne
	i32.or
	i32.popcnt
	i32.reinterpret/f32
	i32.rem_s
	i32.rem_u
	i32.rotl
	i32.rotr
	i32.shl
	i32.shr_s
	i32.shr_u
	i32.store a=0 0
	i32.store16 a=0 0
	i32.store8 a=0 0
	i32.sub
	i32.trunc_s/f32
	i32.trunc_s/f64
	i32.trunc_u/f32
	i32.trunc_u/f64
	i32.wrap/i64
	i32.xor
	i64.add
	i64.and
	i64.clz
	i64.const 0xdeadbeefdeadbeef
	i64.ctz
	i64.div_s
	i64.div_u
	i64.eq
	i64.eqz
	i64.extend_s/i32
	i64.extend_u/i32
	i64.ge_s
	i64.ge_u
	i64.gt_s
	i64.gt_u
	i64.le_s
	i64.le_u
	i64.load a=0 0
	i64.load16_s a=0 0
	i64.load16_u a=0 0
	i64.load32_s a=0 0
	i64.load32_u a=0 0
	i64.load8_s a=0 0
	i64.load8_u a=0 0
	i64.lt_s
	i64.lt_u
	i64.mul
	i64.ne
	i64.or
	i64.popcnt
	i64.reinterpret/f64
	i64.rem_s
	i64.rem_u
	i64.rotl
	i64.rotr
	i64.shl
	i64.shr_s
	i64.shr_u
	i64.store a=0 0
	i64.store16 a=0 0
	i64.store32 a=0 0
	i64.store8 a=0 0
	i64.sub
	i64.trunc_s/f32
	i64.trunc_s/f64
	i64.trunc_u/f32
	i64.trunc_u/f64
	i64.xor
	if[i]
	loop[l]
	nop
	return
	select
	set_global 0
	set_local 0
        signature FvildffdliE
	tee_local 0
	unreachable
