.* Assembler messages:
.*:5: Error: all tmm registers must be distinct for `tcmmimfp16ps'
.*:6: Error: all tmm registers must be distinct for `tcmmimfp16ps'
.*:7: Error: all tmm registers must be distinct for `tcmmimfp16ps'
.*:10: Error: all tmm registers must be distinct for `tcmmimfp16ps'
.*:11: Error: all tmm registers must be distinct for `tcmmimfp16ps'
.*:12: Error: all tmm registers must be distinct for `tcmmimfp16ps'
