# objdump: -dr
# as: -linkrelax
# source: sync-op.s
.*:     file format elf64-mmix

Disassembly of section .text:

0000000000000000 <Main>:
   0:	fc6e6406 	sync 7234566
   4:	fc000000 	sync 0
   8:	fc000001 	sync 1
   c:	fc000000 	sync 0
  10:	fc000001 	sync 1
  14:	fc7c2242 	sync 8135234
