#PROG: objcopy
#as: --32 -mx86-used-note=yes
#objcopy:
#readelf: -n

Displaying notes found in: .note.gnu.property
[ 	]+Owner[ 	]+Data size[ 	]+Description
  GNU                  0x00000008	NT_GNU_PROPERTY_TYPE_0
      Properties: no copy on protected 
  GNU                  0x00000018	NT_GNU_PROPERTY_TYPE_0
      Properties: x86 ISA used: 
	x86 feature used: x86
