.*illegal.s: Assembler messages:
.*illegal.s:5: Error: unknown register r56
.*illegal.s:8: Error: unrecognised instruction fop
.*illegal.s:10: Error: too many arguments
.*illegal.s:11: Error: too many arguments
