; Test C64x+ ddec compact instruction format
	.text
ddec:
	nop
	.align 16
	nop
	.align 16
	.short 0x4c04
	.short 0x5c04
	.short 0x4e04
	.short 0x4c0c
	.short 0x4c05
	.short 0x5c05
	.short 0x4e05
	.short 0x4c0d
	.short 0x5c05
	.short 0x4c05
	.short 0x5e0d
	.short 0x6e0d
	.short 0x7e1d
	.short 0x6e1d
	.word  0xefe00000
	.short 0x4c04
	.short 0x5c04
	.short 0x4e04
	.short 0x4c0c
	.short 0x4c05
	.short 0x5c05
	.short 0x4e05
	.short 0x4c0d
	.short 0x5c05
	.short 0x4e05
	.short 0x5e0d
	.short 0x6e0d
	.short 0x7e1d
	.short 0x6e1d
	.word  0xefe8c000
	.short 0x4c04
	.short 0x5c04
	.short 0x4e04
	.short 0x4c0c
	.short 0x4c05
	.short 0x5c05
	.short 0x4e05
	.short 0x4c0d
	.short 0x5c05
	.short 0x4e05
	.short 0x5e0d
	.short 0x6e0d
	.short 0x7e1d
	.short 0x6e1d
	.word  0xefe9c000
	.short 0x4c04
	.short 0x5c04
	.short 0x4e04
	.short 0x4c0c
	.short 0x4c05
	.short 0x5c05
	.short 0x4e05
	.short 0x4c0d
	.short 0x5c05
	.short 0x4e05
	.short 0x5e0d
	.short 0x6e0d
	.short 0x7e1d
	.short 0x6e1d
	.word  0xefeac000
	.short 0x4e04
	.short 0x5e04
	.short 0x4e04
	.short 0x4c0c
	.short 0x4c05
	.short 0x5c05
	.short 0x4e05
	.short 0x4c0d
	.short 0x5c05
	.short 0x4e05
	.short 0x5e0d
	.short 0x6e0d
	.short 0x7e1d
	.short 0x6e1d
	.word  0xefebc000
	.short 0x4c04
	.short 0x5c04
	.short 0x4e04
	.short 0x4c0c
	.short 0x4c05
	.short 0x5c05
	.short 0x4e05
	.short 0x4c0d
	.short 0x5c05
	.short 0x4e05
	.short 0x5e0d
	.short 0x6e0d
	.short 0x7e1d
	.short 0x6e1d
	.word  0xefecc000
	.short 0x4c04
	.short 0x5c04
	.short 0x4e04
	.short 0x4c0c
	.short 0x4c05
	.short 0x5c05
	.short 0x4e05
	.short 0x4c0d
	.short 0x5c05
	.short 0x4e05
	.short 0x5e0d
	.short 0x6e0d
	.short 0x7e1d
	.short 0x6e1d
	.word  0xefedc000
	.short 0x4c04
	.short 0x5c04
	.short 0x4e04
	.short 0x4c0c
	.short 0x4c05
	.short 0x5c05
	.short 0x4e05
	.short 0x4c0d
	.short 0x5c05
	.short 0x4e05
	.short 0x5e0d
	.short 0x6e0d
	.short 0x7e1d
	.short 0x6e1d
	.word  0xefeec000
	.short 0x4c04
	.short 0x5c04
	.short 0x4e04
	.short 0x4c0c
	.short 0x4c05
	.short 0x5c05
	.short 0x4e05
	.short 0x4c0d
	.short 0x5c05
	.short 0x4e05
	.short 0x5e0d
	.short 0x6e0d
	.short 0x7e1d
	.short 0x6e1d
	.word  0xefefc000
	.short 0x4c14
	.short 0x5c14
	.short 0x4e14
	.short 0x4c1c
	.short 0x4c15
	.short 0x5c15
	.short 0x4e15
	.short 0x4c1d
	.short 0x5c15
	.short 0x4e15
	.short 0x5e1d
	.short 0x6e1d
	.short 0x7e1d
	.short 0x6e1d
	.word  0xefefc000
