## CFA register is not defined to be SP/FP.
## No SFrame stack trace info for this function will be generated.
	.cfi_startproc simple
	.long 0
	.long 0
	.cfi_adjust_cfa_offset 16
	.long 0
	.cfi_endproc
