.*: Assembler messages:
.*:5: Error: opcode not supported on this processor: interaptiv-mr2 \(mips32r3\) `dli \$2,0x9000000080000000'
.*:7: Warning: the `dsp' extension requires MIPS64 revision 2 or greater
.*:7: Warning: the `eva' extension requires MIPS64 revision 2 or greater
.*:7: Warning: the `mt' extension requires MIPS64 revision 2 or greater
.*:7: Warning: the `mips16e2' extension requires MIPS64 revision 2 or greater
.*:10: Error: opcode not supported on this processor: interaptiv-mr2 \(mips32r3\) `dli \$2,0x9000000080000000'
.*:13: Error: opcode not supported on this processor: interaptiv-mr2 \(mips32r3\) `dli \$2,0x9000000080000000'
