[^:]*: Assembler messages:
[^:]*: Warning: multibyte character \(0xe2\) encountered in .*
[^:]*: Warning: multibyte character \(0x80\) encountered in .*
[^:]*: Warning: multibyte character \(0xae\) encountered in .*
[^:]*: Warning: multibyte character \(0xe2\) encountered in .*
[^:]*: Warning: multibyte character \(0x80\) encountered in .*
[^:]*: Warning: multibyte character \(0xac\) encountered in .*
[^:]*: Warning: multibyte character \(0xe2\) encountered in .*
[^:]*: Warning: multibyte character \(0x80\) encountered in .*
[^:]*: Warning: multibyte character \(0xae\) encountered in .*
[^:]*: Warning: multibyte character \(0xe2\) encountered in .*
[^:]*: Warning: further multibyte character warnings suppressed
