[^ :]+: Assembler messages:
[^ :]+:[0-9]+: Error: selected processor does not support system register name 'vdisr_el3'
[^ :]+:[0-9]+:  Info: macro invoked from here
[^ :]+:[0-9]+: Error: selected processor does not support system register name 'vdisr_el3'
[^ :]+:[0-9]+:  Info: macro invoked from here
[^ :]+:[0-9]+: Error: selected processor does not support system register name 'vsesr_el3'
[^ :]+:[0-9]+:  Info: macro invoked from here
[^ :]+:[0-9]+: Error: selected processor does not support system register name 'vsesr_el3'
[^ :]+:[0-9]+:  Info: macro invoked from here
[^ :]+:[0-9]+: Error: selected processor does not support system register name 'spmzr_el0'
[^ :]+:[0-9]+:  Info: macro invoked from here
[^ :]+:[0-9]+: Error: selected processor does not support system register name 'spmzr_el0'
[^ :]+:[0-9]+:  Info: macro invoked from here
[^ :]+:[0-9]+: Error: selected processor does not support system register name 'mdstepop_el1'
[^ :]+:[0-9]+:  Info: macro invoked from here
[^ :]+:[0-9]+: Error: selected processor does not support system register name 'mdstepop_el1'
[^ :]+:[0-9]+:  Info: macro invoked from here