.*: Assembler messages:
.*: Error: unrecognized opcode `cv.beqimm t0,-16,foo', extension `xcvbi' required
.*: Error: unrecognized opcode `cv.beqimm t4,5,foo', extension `xcvbi' required
.*: Error: unrecognized opcode `cv.beqimm t2,15,foo', extension `xcvbi' required
.*: Error: unrecognized opcode `cv.bneimm t0,-16,foo', extension `xcvbi' required
.*: Error: unrecognized opcode `cv.bneimm t4,5,foo', extension `xcvbi' required
.*: Error: unrecognized opcode `cv.bneimm t2,15,foo', extension `xcvbi' required
.*: Error: illegal operands `cv.beqimm 20,10,foo'
.*: Error: illegal operands `cv.bneimm 8,-4,foo'
.*: Error: instruction cv.beqimm requires absolute expression
.*: Error: instruction cv.bneimm requires absolute expression
.*: Error: illegal operands `cv.beqimm t0,-17,foo'
.*: Error: illegal operands `cv.beqimm t2,-32,foo'
.*: Error: illegal operands `cv.beqimm t4,16,foo'
.*: Error: illegal operands `cv.beqimm t3,44,foo'
.*: Error: illegal operands `cv.bneimm t0,-17,foo'
.*: Error: illegal operands `cv.bneimm t2,-32,foo'
.*: Error: illegal operands `cv.bneimm t4,16,foo'
.*: Error: illegal operands `cv.bneimm t3,44,foo'
