MACHINE=
SCRIPT_NAME=elfm68hc11
OUTPUT_FORMAT="elf32-m68hc11"
TEXT_MEMORY=text
DATA_MEMORY=data
EEPROM_MEMORY=eeprom
ARCH=m68hc11
MAXPAGESIZE=32
GENERIC_BOARD=yes
TEMPLATE_NAME=elf
EXTRA_EM_FILE=m68hc1xelf

